/* DataImportsUI.c generated by valac 0.32.1, the Vala compiler
 * generated from DataImportsUI.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include "shotwell-plugin-dev-1.0.h"
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <float.h>
#include <math.h>
#include <gdk/gdk.h>


#define DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE (data_imports_ui_concrete_dialog_pane_get_type ())
#define DATA_IMPORTS_UI_CONCRETE_DIALOG_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, DataImportsUIConcreteDialogPane))
#define DATA_IMPORTS_UI_CONCRETE_DIALOG_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, DataImportsUIConcreteDialogPaneClass))
#define DATA_IMPORTS_UI_IS_CONCRETE_DIALOG_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE))
#define DATA_IMPORTS_UI_IS_CONCRETE_DIALOG_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE))
#define DATA_IMPORTS_UI_CONCRETE_DIALOG_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, DataImportsUIConcreteDialogPaneClass))

typedef struct _DataImportsUIConcreteDialogPane DataImportsUIConcreteDialogPane;
typedef struct _DataImportsUIConcreteDialogPaneClass DataImportsUIConcreteDialogPaneClass;
typedef struct _DataImportsUIConcreteDialogPanePrivate DataImportsUIConcreteDialogPanePrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define DATA_IMPORTS_UI_TYPE_STATIC_MESSAGE_PANE (data_imports_ui_static_message_pane_get_type ())
#define DATA_IMPORTS_UI_STATIC_MESSAGE_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_UI_TYPE_STATIC_MESSAGE_PANE, DataImportsUIStaticMessagePane))
#define DATA_IMPORTS_UI_STATIC_MESSAGE_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_UI_TYPE_STATIC_MESSAGE_PANE, DataImportsUIStaticMessagePaneClass))
#define DATA_IMPORTS_UI_IS_STATIC_MESSAGE_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_UI_TYPE_STATIC_MESSAGE_PANE))
#define DATA_IMPORTS_UI_IS_STATIC_MESSAGE_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_UI_TYPE_STATIC_MESSAGE_PANE))
#define DATA_IMPORTS_UI_STATIC_MESSAGE_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_UI_TYPE_STATIC_MESSAGE_PANE, DataImportsUIStaticMessagePaneClass))

typedef struct _DataImportsUIStaticMessagePane DataImportsUIStaticMessagePane;
typedef struct _DataImportsUIStaticMessagePaneClass DataImportsUIStaticMessagePaneClass;
typedef struct _DataImportsUIStaticMessagePanePrivate DataImportsUIStaticMessagePanePrivate;

#define DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE (data_imports_ui_library_selection_pane_get_type ())
#define DATA_IMPORTS_UI_LIBRARY_SELECTION_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE, DataImportsUILibrarySelectionPane))
#define DATA_IMPORTS_UI_LIBRARY_SELECTION_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE, DataImportsUILibrarySelectionPaneClass))
#define DATA_IMPORTS_UI_IS_LIBRARY_SELECTION_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE))
#define DATA_IMPORTS_UI_IS_LIBRARY_SELECTION_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE))
#define DATA_IMPORTS_UI_LIBRARY_SELECTION_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE, DataImportsUILibrarySelectionPaneClass))

typedef struct _DataImportsUILibrarySelectionPane DataImportsUILibrarySelectionPane;
typedef struct _DataImportsUILibrarySelectionPaneClass DataImportsUILibrarySelectionPaneClass;
typedef struct _DataImportsUILibrarySelectionPanePrivate DataImportsUILibrarySelectionPanePrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _Block10Data Block10Data;
typedef struct _Block11Data Block11Data;

#define DATA_IMPORTS_UI_TYPE_PROGRESS_PANE (data_imports_ui_progress_pane_get_type ())
#define DATA_IMPORTS_UI_PROGRESS_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_UI_TYPE_PROGRESS_PANE, DataImportsUIProgressPane))
#define DATA_IMPORTS_UI_PROGRESS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_UI_TYPE_PROGRESS_PANE, DataImportsUIProgressPaneClass))
#define DATA_IMPORTS_UI_IS_PROGRESS_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_UI_TYPE_PROGRESS_PANE))
#define DATA_IMPORTS_UI_IS_PROGRESS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_UI_TYPE_PROGRESS_PANE))
#define DATA_IMPORTS_UI_PROGRESS_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_UI_TYPE_PROGRESS_PANE, DataImportsUIProgressPaneClass))

typedef struct _DataImportsUIProgressPane DataImportsUIProgressPane;
typedef struct _DataImportsUIProgressPaneClass DataImportsUIProgressPaneClass;
typedef struct _DataImportsUIProgressPanePrivate DataImportsUIProgressPanePrivate;

#define DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG (data_imports_ui_data_imports_dialog_get_type ())
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG, DataImportsUIDataImportsDialog))
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG, DataImportsUIDataImportsDialogClass))
#define DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG))
#define DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG))
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG, DataImportsUIDataImportsDialogClass))

typedef struct _DataImportsUIDataImportsDialog DataImportsUIDataImportsDialog;
typedef struct _DataImportsUIDataImportsDialogClass DataImportsUIDataImportsDialogClass;
typedef struct _DataImportsUIDataImportsDialogPrivate DataImportsUIDataImportsDialogPrivate;

#define PLUGINS_TYPE_STANDARD_HOST_INTERFACE (plugins_standard_host_interface_get_type ())
#define PLUGINS_STANDARD_HOST_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterface))
#define PLUGINS_STANDARD_HOST_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterfaceClass))
#define PLUGINS_IS_STANDARD_HOST_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PLUGINS_TYPE_STANDARD_HOST_INTERFACE))
#define PLUGINS_IS_STANDARD_HOST_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PLUGINS_TYPE_STANDARD_HOST_INTERFACE))
#define PLUGINS_STANDARD_HOST_INTERFACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterfaceClass))

typedef struct _PluginsStandardHostInterface PluginsStandardHostInterface;
typedef struct _PluginsStandardHostInterfaceClass PluginsStandardHostInterfaceClass;

#define SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST (spit_data_imports_concrete_data_imports_host_get_type ())
#define SPIT_DATA_IMPORTS_CONCRETE_DATA_IMPORTS_HOST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost))
#define SPIT_DATA_IMPORTS_CONCRETE_DATA_IMPORTS_HOST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHostClass))
#define SPIT_DATA_IMPORTS_IS_CONCRETE_DATA_IMPORTS_HOST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST))
#define SPIT_DATA_IMPORTS_IS_CONCRETE_DATA_IMPORTS_HOST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST))
#define SPIT_DATA_IMPORTS_CONCRETE_DATA_IMPORTS_HOST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHostClass))

typedef struct _SpitDataImportsConcreteDataImportsHost SpitDataImportsConcreteDataImportsHost;
typedef struct _SpitDataImportsConcreteDataImportsHostClass SpitDataImportsConcreteDataImportsHostClass;

#define TYPE_CONFIGURATION_FACADE (configuration_facade_get_type ())
#define CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacade))
#define CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))
#define IS_CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONFIGURATION_FACADE))
#define IS_CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONFIGURATION_FACADE))
#define CONFIGURATION_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))

typedef struct _ConfigurationFacade ConfigurationFacade;
typedef struct _ConfigurationFacadeClass ConfigurationFacadeClass;

#define CONFIG_TYPE_FACADE (config_facade_get_type ())
#define CONFIG_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONFIG_TYPE_FACADE, ConfigFacade))
#define CONFIG_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONFIG_TYPE_FACADE, ConfigFacadeClass))
#define CONFIG_IS_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONFIG_TYPE_FACADE))
#define CONFIG_IS_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONFIG_TYPE_FACADE))
#define CONFIG_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONFIG_TYPE_FACADE, ConfigFacadeClass))

typedef struct _ConfigFacade ConfigFacade;
typedef struct _ConfigFacadeClass ConfigFacadeClass;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _DataImportsUIConcreteDialogPane {
	GObject parent_instance;
	DataImportsUIConcreteDialogPanePrivate * priv;
};

struct _DataImportsUIConcreteDialogPaneClass {
	GObjectClass parent_class;
};

struct _DataImportsUIConcreteDialogPanePrivate {
	GtkBox* pane_widget;
};

struct _DataImportsUIStaticMessagePane {
	DataImportsUIConcreteDialogPane parent_instance;
	DataImportsUIStaticMessagePanePrivate * priv;
};

struct _DataImportsUIStaticMessagePaneClass {
	DataImportsUIConcreteDialogPaneClass parent_class;
};

struct _DataImportsUILibrarySelectionPane {
	DataImportsUIConcreteDialogPane parent_instance;
	DataImportsUILibrarySelectionPanePrivate * priv;
};

struct _DataImportsUILibrarySelectionPaneClass {
	DataImportsUIConcreteDialogPaneClass parent_class;
};

struct _DataImportsUILibrarySelectionPanePrivate {
	SpitDataImportsPluginHost* host;
	SpitDataImportsImportableLibrary* selected_library;
	GFile* selected_file;
	GtkButton* import_button;
	GtkRadioButton* file_radio;
};

struct _Block10Data {
	int _ref_count_;
	DataImportsUILibrarySelectionPane* self;
	GtkFileChooserButton* file_chooser;
};

struct _Block11Data {
	int _ref_count_;
	DataImportsUILibrarySelectionPane* self;
	GtkRadioButton* button;
	SpitDataImportsImportableLibrary* library;
};

struct _DataImportsUIProgressPane {
	DataImportsUIConcreteDialogPane parent_instance;
	DataImportsUIProgressPanePrivate * priv;
};

struct _DataImportsUIProgressPaneClass {
	DataImportsUIConcreteDialogPaneClass parent_class;
};

struct _DataImportsUIProgressPanePrivate {
	GtkLabel* message_label;
	GtkLabel* progress_label;
	GtkProgressBar* progress_bar;
};

struct _DataImportsUIDataImportsDialog {
	GtkDialog parent_instance;
	DataImportsUIDataImportsDialogPrivate * priv;
};

struct _DataImportsUIDataImportsDialogClass {
	GtkDialogClass parent_class;
};

struct _DataImportsUIDataImportsDialogPrivate {
	GtkComboBoxText* service_selector_box;
	GtkBox* central_area_layouter;
	GtkButton* close_cancel_button;
	SpitDataImportsDialogPane* active_pane;
	SpitDataImportsConcreteDataImportsHost* host;
};


static gpointer data_imports_ui_concrete_dialog_pane_parent_class = NULL;
static SpitDataImportsDialogPaneIface* data_imports_ui_concrete_dialog_pane_spit_data_imports_dialog_pane_parent_iface = NULL;
static gpointer data_imports_ui_static_message_pane_parent_class = NULL;
static gpointer data_imports_ui_library_selection_pane_parent_class = NULL;
static gpointer data_imports_ui_progress_pane_parent_class = NULL;
static gpointer data_imports_ui_data_imports_dialog_parent_class = NULL;
static DataImportsUIDataImportsDialog* data_imports_ui_data_imports_dialog_instance;
static DataImportsUIDataImportsDialog* data_imports_ui_data_imports_dialog_instance = NULL;

#define DATA_IMPORTS_UI_NO_PLUGINS_ENABLED_MESSAGE _ ("You do not have any data imports plugins enabled.\n" \
"\n" \
"In order to use the Import From Application functionality, you need to" \
" have at least one data imports plugin enabled. Plugins can be enabled" \
" in the Preferences dialog.")
GType data_imports_ui_concrete_dialog_pane_get_type (void) G_GNUC_CONST;
#define DATA_IMPORTS_UI_CONCRETE_DIALOG_PANE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, DataImportsUIConcreteDialogPanePrivate))
enum  {
	DATA_IMPORTS_UI_CONCRETE_DIALOG_PANE_DUMMY_PROPERTY
};
DataImportsUIConcreteDialogPane* data_imports_ui_concrete_dialog_pane_new (void);
DataImportsUIConcreteDialogPane* data_imports_ui_concrete_dialog_pane_construct (GType object_type);
static GtkWidget* data_imports_ui_concrete_dialog_pane_real_get_widget (SpitDataImportsDialogPane* base);
static SpitDataImportsDialogPaneGeometryOptions data_imports_ui_concrete_dialog_pane_real_get_preferred_geometry (SpitDataImportsDialogPane* base);
static void data_imports_ui_concrete_dialog_pane_real_on_pane_installed (SpitDataImportsDialogPane* base);
static void data_imports_ui_concrete_dialog_pane_real_on_pane_uninstalled (SpitDataImportsDialogPane* base);
static void data_imports_ui_concrete_dialog_pane_finalize (GObject* obj);
GType data_imports_ui_static_message_pane_get_type (void) G_GNUC_CONST;
enum  {
	DATA_IMPORTS_UI_STATIC_MESSAGE_PANE_DUMMY_PROPERTY
};
DataImportsUIStaticMessagePane* data_imports_ui_static_message_pane_new (const gchar* message_string);
DataImportsUIStaticMessagePane* data_imports_ui_static_message_pane_construct (GType object_type, const gchar* message_string);
DataImportsUIStaticMessagePane* data_imports_ui_static_message_pane_new_with_pango (const gchar* msg);
DataImportsUIStaticMessagePane* data_imports_ui_static_message_pane_construct_with_pango (GType object_type, const gchar* msg);
GType data_imports_ui_library_selection_pane_get_type (void) G_GNUC_CONST;
#define DATA_IMPORTS_UI_LIBRARY_SELECTION_PANE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE, DataImportsUILibrarySelectionPanePrivate))
enum  {
	DATA_IMPORTS_UI_LIBRARY_SELECTION_PANE_DUMMY_PROPERTY
};
DataImportsUILibrarySelectionPane* data_imports_ui_library_selection_pane_new (SpitDataImportsPluginHost* host, const gchar* welcome_message, SpitDataImportsImportableLibrary** discovered_libraries, int discovered_libraries_length1, const gchar* file_select_label);
DataImportsUILibrarySelectionPane* data_imports_ui_library_selection_pane_construct (GType object_type, SpitDataImportsPluginHost* host, const gchar* welcome_message, SpitDataImportsImportableLibrary** discovered_libraries, int discovered_libraries_length1, const gchar* file_select_label);
static void data_imports_ui_library_selection_pane_on_file_selected (DataImportsUILibrarySelectionPane* self, GFile* file);
static GtkRadioButton* data_imports_ui_library_selection_pane_create_radio_button (DataImportsUILibrarySelectionPane* self, GtkBox* box, GtkRadioButton* group, SpitDataImportsImportableLibrary* library, const gchar* label, gint margin_left, gint margin_right);
static Block10Data* block10_data_ref (Block10Data* _data10_);
static void block10_data_unref (void * _userdata_);
static void ___lambda19_ (Block10Data* _data10_);
static void data_imports_ui_library_selection_pane_set_import_button_sensitivity (DataImportsUILibrarySelectionPane* self);
static void ____lambda19__gtk_file_chooser_selection_changed (GtkFileChooser* _sender, gpointer self);
static void __lambda20_ (DataImportsUILibrarySelectionPane* self);
static void data_imports_ui_library_selection_pane_on_library_selected (DataImportsUILibrarySelectionPane* self, SpitDataImportsImportableLibrary* library);
static void ___lambda20__gtk_button_clicked (GtkButton* _sender, gpointer self);
static Block11Data* block11_data_ref (Block11Data* _data11_);
static void block11_data_unref (void * _userdata_);
static void __lambda18_ (Block11Data* _data11_);
static void ___lambda18__gtk_toggle_button_toggled (GtkToggleButton* _sender, gpointer self);
static void data_imports_ui_library_selection_pane_finalize (GObject* obj);
GType data_imports_ui_progress_pane_get_type (void) G_GNUC_CONST;
#define DATA_IMPORTS_UI_PROGRESS_PANE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DATA_IMPORTS_UI_TYPE_PROGRESS_PANE, DataImportsUIProgressPanePrivate))
enum  {
	DATA_IMPORTS_UI_PROGRESS_PANE_DUMMY_PROPERTY
};
DataImportsUIProgressPane* data_imports_ui_progress_pane_new (const gchar* message);
DataImportsUIProgressPane* data_imports_ui_progress_pane_construct (GType object_type, const gchar* message);
void data_imports_ui_progress_pane_update_progress (DataImportsUIProgressPane* self, gdouble progress, const gchar* progress_message);
void spin_event_loop (void);
static void data_imports_ui_progress_pane_finalize (GObject* obj);
GType data_imports_ui_data_imports_dialog_get_type (void) G_GNUC_CONST;
GType plugins_standard_host_interface_get_type (void) G_GNUC_CONST;
GType spit_data_imports_concrete_data_imports_host_get_type (void) G_GNUC_CONST;
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG, DataImportsUIDataImportsDialogPrivate))
enum  {
	DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_DUMMY_PROPERTY
};
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_LARGE_WINDOW_WIDTH 860
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_LARGE_WINDOW_HEIGHT 688
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_COLOSSAL_WINDOW_WIDTH 1024
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_COLOSSAL_WINDOW_HEIGHT 688
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_STANDARD_WINDOW_WIDTH 600
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_STANDARD_WINDOW_HEIGHT 510
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_BORDER_REGION_WIDTH 16
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_BORDER_REGION_HEIGHT 100
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_STANDARD_CONTENT_LABEL_WIDTH 500
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_STANDARD_ACTION_BUTTON_WIDTH 128
DataImportsUIDataImportsDialog* data_imports_ui_data_imports_dialog_new (void);
DataImportsUIDataImportsDialog* data_imports_ui_data_imports_dialog_construct (GType object_type);
static gboolean data_imports_ui_data_imports_dialog_on_window_close (DataImportsUIDataImportsDialog* self, GdkEventAny* evt);
static gboolean _data_imports_ui_data_imports_dialog_on_window_close_gtk_widget_delete_event (GtkWidget* _sender, GdkEventAny* event, gpointer self);
SpitDataImportsService** spit_data_imports_load_services (gboolean load_all, int* result_length1);
GType configuration_facade_get_type (void) G_GNUC_CONST;
GType config_facade_get_type (void) G_GNUC_CONST;
ConfigFacade* config_facade_get_instance (void);
gchar* configuration_facade_get_last_used_dataimports_service (ConfigurationFacade* self);
static void data_imports_ui_data_imports_dialog_on_service_changed (DataImportsUIDataImportsDialog* self);
static void _data_imports_ui_data_imports_dialog_on_service_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self);
static void data_imports_ui_data_imports_dialog_on_close_cancel_clicked (DataImportsUIDataImportsDialog* self);
static void _data_imports_ui_data_imports_dialog_on_close_cancel_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void data_imports_ui_data_imports_dialog_set_standard_window_mode (DataImportsUIDataImportsDialog* self);
void data_imports_ui_data_imports_dialog_install_pane (DataImportsUIDataImportsDialog* self, SpitDataImportsDialogPane* pane);
void data_imports_ui_data_imports_dialog_set_close_button_mode (DataImportsUIDataImportsDialog* self);
DataImportsUIDataImportsDialog* data_imports_ui_data_imports_dialog_get_or_create_instance (void);
void data_imports_ui_data_imports_dialog_terminate_instance (void);
static void data_imports_ui_data_imports_dialog_terminate (DataImportsUIDataImportsDialog* self);
SpitDataImportsService** spit_data_imports_load_all_services (int* result_length1);
void configuration_facade_set_last_used_dataimports_service (ConfigurationFacade* self, const gchar* service_name);
SpitDataImportsConcreteDataImportsHost* spit_data_imports_concrete_data_imports_host_new (SpitDataImportsService* service, DataImportsUIDataImportsDialog* dialog);
SpitDataImportsConcreteDataImportsHost* spit_data_imports_concrete_data_imports_host_construct (GType object_type, SpitDataImportsService* service, DataImportsUIDataImportsDialog* dialog);
static void data_imports_ui_data_imports_dialog_set_large_window_mode (DataImportsUIDataImportsDialog* self);
static void data_imports_ui_data_imports_dialog_set_colossal_window_mode (DataImportsUIDataImportsDialog* self);
static void data_imports_ui_data_imports_dialog_set_free_sizable_window_mode (DataImportsUIDataImportsDialog* self);
static void data_imports_ui_data_imports_dialog_clear_free_sizable_window_mode (DataImportsUIDataImportsDialog* self);
SpitDataImportsDialogPane* data_imports_ui_data_imports_dialog_get_active_pane (DataImportsUIDataImportsDialog* self);
void data_imports_ui_data_imports_dialog_set_cancel_button_mode (DataImportsUIDataImportsDialog* self);
void data_imports_ui_data_imports_dialog_lock_service (DataImportsUIDataImportsDialog* self);
void data_imports_ui_data_imports_dialog_unlock_service (DataImportsUIDataImportsDialog* self);
static void data_imports_ui_data_imports_dialog_finalize (GObject* obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


DataImportsUIConcreteDialogPane* data_imports_ui_concrete_dialog_pane_construct (GType object_type) {
	DataImportsUIConcreteDialogPane * self = NULL;
	GtkBox* _tmp0_ = NULL;
#line 15 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = (DataImportsUIConcreteDialogPane*) g_object_new (object_type, NULL);
#line 16 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 8);
#line 16 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_ref_sink (_tmp0_);
#line 16 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 16 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv->pane_widget = _tmp0_;
#line 15 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return self;
#line 342 "DataImportsUI.c"
}


DataImportsUIConcreteDialogPane* data_imports_ui_concrete_dialog_pane_new (void) {
#line 15 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return data_imports_ui_concrete_dialog_pane_construct (DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE);
#line 349 "DataImportsUI.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 20 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return self ? g_object_ref (self) : NULL;
#line 356 "DataImportsUI.c"
}


static GtkWidget* data_imports_ui_concrete_dialog_pane_real_get_widget (SpitDataImportsDialogPane* base) {
	DataImportsUIConcreteDialogPane * self;
	GtkWidget* result = NULL;
	GtkBox* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
#line 19 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, DataImportsUIConcreteDialogPane);
#line 20 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->pane_widget;
#line 20 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 20 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	result = _tmp1_;
#line 20 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return result;
#line 375 "DataImportsUI.c"
}


static SpitDataImportsDialogPaneGeometryOptions data_imports_ui_concrete_dialog_pane_real_get_preferred_geometry (SpitDataImportsDialogPane* base) {
	DataImportsUIConcreteDialogPane * self;
	SpitDataImportsDialogPaneGeometryOptions result = 0;
#line 23 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, DataImportsUIConcreteDialogPane);
#line 24 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	result = SPIT_DATA_IMPORTS_DIALOG_PANE_GEOMETRY_OPTIONS_NONE;
#line 24 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return result;
#line 388 "DataImportsUI.c"
}


static void data_imports_ui_concrete_dialog_pane_real_on_pane_installed (SpitDataImportsDialogPane* base) {
	DataImportsUIConcreteDialogPane * self;
#line 27 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, DataImportsUIConcreteDialogPane);
#line 396 "DataImportsUI.c"
}


static void data_imports_ui_concrete_dialog_pane_real_on_pane_uninstalled (SpitDataImportsDialogPane* base) {
	DataImportsUIConcreteDialogPane * self;
#line 30 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, DataImportsUIConcreteDialogPane);
#line 404 "DataImportsUI.c"
}


static void data_imports_ui_concrete_dialog_pane_class_init (DataImportsUIConcreteDialogPaneClass * klass) {
#line 12 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_concrete_dialog_pane_parent_class = g_type_class_peek_parent (klass);
#line 12 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_type_class_add_private (klass, sizeof (DataImportsUIConcreteDialogPanePrivate));
#line 12 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	G_OBJECT_CLASS (klass)->finalize = data_imports_ui_concrete_dialog_pane_finalize;
#line 415 "DataImportsUI.c"
}


static void data_imports_ui_concrete_dialog_pane_spit_data_imports_dialog_pane_interface_init (SpitDataImportsDialogPaneIface * iface) {
#line 12 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_concrete_dialog_pane_spit_data_imports_dialog_pane_parent_iface = g_type_interface_peek_parent (iface);
#line 12 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	iface->get_widget = (GtkWidget* (*)(SpitDataImportsDialogPane*)) data_imports_ui_concrete_dialog_pane_real_get_widget;
#line 12 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	iface->get_preferred_geometry = (SpitDataImportsDialogPaneGeometryOptions (*)(SpitDataImportsDialogPane*)) data_imports_ui_concrete_dialog_pane_real_get_preferred_geometry;
#line 12 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	iface->on_pane_installed = (void (*)(SpitDataImportsDialogPane*)) data_imports_ui_concrete_dialog_pane_real_on_pane_installed;
#line 12 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	iface->on_pane_uninstalled = (void (*)(SpitDataImportsDialogPane*)) data_imports_ui_concrete_dialog_pane_real_on_pane_uninstalled;
#line 430 "DataImportsUI.c"
}


static void data_imports_ui_concrete_dialog_pane_instance_init (DataImportsUIConcreteDialogPane * self) {
#line 12 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv = DATA_IMPORTS_UI_CONCRETE_DIALOG_PANE_GET_PRIVATE (self);
#line 437 "DataImportsUI.c"
}


static void data_imports_ui_concrete_dialog_pane_finalize (GObject* obj) {
	DataImportsUIConcreteDialogPane * self;
#line 12 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, DataImportsUIConcreteDialogPane);
#line 13 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 12 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	G_OBJECT_CLASS (data_imports_ui_concrete_dialog_pane_parent_class)->finalize (obj);
#line 449 "DataImportsUI.c"
}


GType data_imports_ui_concrete_dialog_pane_get_type (void) {
	static volatile gsize data_imports_ui_concrete_dialog_pane_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_ui_concrete_dialog_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsUIConcreteDialogPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_ui_concrete_dialog_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsUIConcreteDialogPane), 0, (GInstanceInitFunc) data_imports_ui_concrete_dialog_pane_instance_init, NULL };
		static const GInterfaceInfo spit_data_imports_dialog_pane_info = { (GInterfaceInitFunc) data_imports_ui_concrete_dialog_pane_spit_data_imports_dialog_pane_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType data_imports_ui_concrete_dialog_pane_type_id;
		data_imports_ui_concrete_dialog_pane_type_id = g_type_register_static (G_TYPE_OBJECT, "DataImportsUIConcreteDialogPane", &g_define_type_info, 0);
		g_type_add_interface_static (data_imports_ui_concrete_dialog_pane_type_id, SPIT_DATA_IMPORTS_TYPE_DIALOG_PANE, &spit_data_imports_dialog_pane_info);
		g_once_init_leave (&data_imports_ui_concrete_dialog_pane_type_id__volatile, data_imports_ui_concrete_dialog_pane_type_id);
	}
	return data_imports_ui_concrete_dialog_pane_type_id__volatile;
}


DataImportsUIStaticMessagePane* data_imports_ui_static_message_pane_construct (GType object_type, const gchar* message_string) {
	DataImportsUIStaticMessagePane * self = NULL;
	GtkLabel* message_label = NULL;
	const gchar* _tmp0_ = NULL;
	GtkLabel* _tmp1_ = NULL;
	GtkWidget* _tmp2_ = NULL;
	GtkBox* _tmp3_ = NULL;
	GtkBox* _tmp4_ = NULL;
#line 35 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_val_if_fail (message_string != NULL, NULL);
#line 35 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = (DataImportsUIStaticMessagePane*) data_imports_ui_concrete_dialog_pane_construct (object_type);
#line 36 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = message_string;
#line 36 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = (GtkLabel*) gtk_label_new (_tmp0_);
#line 36 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_ref_sink (_tmp1_);
#line 36 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	message_label = _tmp1_;
#line 37 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp2_ = spit_data_imports_dialog_pane_get_widget (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_DIALOG_PANE, SpitDataImportsDialogPane));
#line 37 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp3_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, gtk_box_get_type ()) ? ((GtkBox*) _tmp2_) : NULL;
#line 37 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp3_ == NULL) {
#line 37 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (_tmp2_);
#line 495 "DataImportsUI.c"
	}
#line 37 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp4_ = _tmp3_;
#line 37 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_box_pack_start (_tmp4_, G_TYPE_CHECK_INSTANCE_CAST (message_label, gtk_widget_get_type (), GtkWidget), TRUE, TRUE, (guint) 0);
#line 37 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (_tmp4_);
#line 35 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (message_label);
#line 35 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return self;
#line 507 "DataImportsUI.c"
}


DataImportsUIStaticMessagePane* data_imports_ui_static_message_pane_new (const gchar* message_string) {
#line 35 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return data_imports_ui_static_message_pane_construct (DATA_IMPORTS_UI_TYPE_STATIC_MESSAGE_PANE, message_string);
#line 514 "DataImportsUI.c"
}


DataImportsUIStaticMessagePane* data_imports_ui_static_message_pane_construct_with_pango (GType object_type, const gchar* msg) {
	DataImportsUIStaticMessagePane * self = NULL;
	GtkLabel* label = NULL;
	GtkLabel* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GtkWidget* _tmp2_ = NULL;
	GtkBox* _tmp3_ = NULL;
	GtkBox* _tmp4_ = NULL;
#line 40 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_val_if_fail (msg != NULL, NULL);
#line 40 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = (DataImportsUIStaticMessagePane*) data_imports_ui_concrete_dialog_pane_construct (object_type);
#line 41 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = (GtkLabel*) gtk_label_new (NULL);
#line 41 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_ref_sink (_tmp0_);
#line 41 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	label = _tmp0_;
#line 42 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = msg;
#line 42 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_label_set_markup (label, _tmp1_);
#line 43 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_label_set_line_wrap (label, TRUE);
#line 45 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp2_ = spit_data_imports_dialog_pane_get_widget (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_DIALOG_PANE, SpitDataImportsDialogPane));
#line 45 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp3_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, gtk_box_get_type ()) ? ((GtkBox*) _tmp2_) : NULL;
#line 45 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp3_ == NULL) {
#line 45 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (_tmp2_);
#line 550 "DataImportsUI.c"
	}
#line 45 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp4_ = _tmp3_;
#line 45 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_box_pack_start (_tmp4_, G_TYPE_CHECK_INSTANCE_CAST (label, gtk_widget_get_type (), GtkWidget), TRUE, TRUE, (guint) 0);
#line 45 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (_tmp4_);
#line 40 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (label);
#line 40 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return self;
#line 562 "DataImportsUI.c"
}


DataImportsUIStaticMessagePane* data_imports_ui_static_message_pane_new_with_pango (const gchar* msg) {
#line 40 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return data_imports_ui_static_message_pane_construct_with_pango (DATA_IMPORTS_UI_TYPE_STATIC_MESSAGE_PANE, msg);
#line 569 "DataImportsUI.c"
}


static void data_imports_ui_static_message_pane_class_init (DataImportsUIStaticMessagePaneClass * klass) {
#line 34 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_static_message_pane_parent_class = g_type_class_peek_parent (klass);
#line 576 "DataImportsUI.c"
}


static void data_imports_ui_static_message_pane_instance_init (DataImportsUIStaticMessagePane * self) {
}


GType data_imports_ui_static_message_pane_get_type (void) {
	static volatile gsize data_imports_ui_static_message_pane_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_ui_static_message_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsUIStaticMessagePaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_ui_static_message_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsUIStaticMessagePane), 0, (GInstanceInitFunc) data_imports_ui_static_message_pane_instance_init, NULL };
		GType data_imports_ui_static_message_pane_type_id;
		data_imports_ui_static_message_pane_type_id = g_type_register_static (DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, "DataImportsUIStaticMessagePane", &g_define_type_info, 0);
		g_once_init_leave (&data_imports_ui_static_message_pane_type_id__volatile, data_imports_ui_static_message_pane_type_id);
	}
	return data_imports_ui_static_message_pane_type_id__volatile;
}


static Block10Data* block10_data_ref (Block10Data* _data10_) {
#line 99 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_atomic_int_inc (&_data10_->_ref_count_);
#line 99 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return _data10_;
#line 601 "DataImportsUI.c"
}


static void block10_data_unref (void * _userdata_) {
	Block10Data* _data10_;
	_data10_ = (Block10Data*) _userdata_;
#line 99 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (g_atomic_int_dec_and_test (&_data10_->_ref_count_)) {
#line 610 "DataImportsUI.c"
		DataImportsUILibrarySelectionPane* self;
#line 99 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		self = _data10_->self;
#line 99 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (_data10_->file_chooser);
#line 99 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (self);
#line 99 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		g_slice_free (Block10Data, _data10_);
#line 620 "DataImportsUI.c"
	}
}


static void ___lambda19_ (Block10Data* _data10_) {
	DataImportsUILibrarySelectionPane* self;
	GtkFileChooserButton* _tmp0_ = NULL;
	GFile* _tmp1_ = NULL;
	GtkRadioButton* _tmp2_ = NULL;
#line 101 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = _data10_->self;
#line 102 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = _data10_->file_chooser;
#line 102 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = gtk_file_chooser_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser));
#line 102 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->selected_file);
#line 102 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv->selected_file = _tmp1_;
#line 103 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp2_ = self->priv->file_radio;
#line 103 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp2_ != NULL) {
#line 644 "DataImportsUI.c"
		GtkRadioButton* _tmp3_ = NULL;
#line 104 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp3_ = self->priv->file_radio;
#line 104 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_toggle_button_get_type (), GtkToggleButton), TRUE);
#line 650 "DataImportsUI.c"
	}
#line 105 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_library_selection_pane_set_import_button_sensitivity (self);
#line 654 "DataImportsUI.c"
}


static void ____lambda19__gtk_file_chooser_selection_changed (GtkFileChooser* _sender, gpointer self) {
#line 101 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	___lambda19_ (self);
#line 661 "DataImportsUI.c"
}


static void __lambda20_ (DataImportsUILibrarySelectionPane* self) {
	SpitDataImportsImportableLibrary* _tmp0_ = NULL;
#line 114 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->selected_library;
#line 114 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp0_ != NULL) {
#line 671 "DataImportsUI.c"
		SpitDataImportsImportableLibrary* _tmp1_ = NULL;
#line 115 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp1_ = self->priv->selected_library;
#line 115 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		data_imports_ui_library_selection_pane_on_library_selected (self, _tmp1_);
#line 677 "DataImportsUI.c"
	} else {
		GFile* _tmp2_ = NULL;
#line 116 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp2_ = self->priv->selected_file;
#line 116 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		if (_tmp2_ != NULL) {
#line 684 "DataImportsUI.c"
			GFile* _tmp3_ = NULL;
#line 117 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp3_ = self->priv->selected_file;
#line 117 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			data_imports_ui_library_selection_pane_on_file_selected (self, _tmp3_);
#line 690 "DataImportsUI.c"
		} else {
#line 119 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			g_debug ("DataImportsUI.vala:119: LibrarySelectionPane: Library or file should b" \
"e selected.");
#line 694 "DataImportsUI.c"
		}
	}
}


static void ___lambda20__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 113 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	__lambda20_ ((DataImportsUILibrarySelectionPane*) self);
#line 703 "DataImportsUI.c"
}


DataImportsUILibrarySelectionPane* data_imports_ui_library_selection_pane_construct (GType object_type, SpitDataImportsPluginHost* host, const gchar* welcome_message, SpitDataImportsImportableLibrary** discovered_libraries, int discovered_libraries_length1, const gchar* file_select_label) {
	DataImportsUILibrarySelectionPane * self = NULL;
	gboolean _tmp0_ = FALSE;
	SpitDataImportsImportableLibrary** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	SpitDataImportsPluginHost* _tmp2_ = NULL;
	GtkBox* content_box = NULL;
	GtkBox* _tmp3_ = NULL;
	GtkBox* _tmp4_ = NULL;
	GtkBox* _tmp5_ = NULL;
	GtkLabel* welcome_label = NULL;
	GtkLabel* _tmp6_ = NULL;
	GtkLabel* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	GtkLabel* _tmp9_ = NULL;
	GtkLabel* _tmp10_ = NULL;
	GtkBox* _tmp11_ = NULL;
	GtkLabel* _tmp12_ = NULL;
	gint radio_margin_left = 0;
	gint radio_margin_right = 0;
	gint chooser_margin_left = 0;
	gint _tmp13_ = 0;
	gint chooser_margin_right = 0;
	gint _tmp14_ = 0;
	GtkRadioButton* lib_radio = NULL;
	SpitDataImportsImportableLibrary** _tmp15_ = NULL;
	gint _tmp15__length1 = 0;
	const gchar* _tmp37_ = NULL;
	const gchar* _tmp47_ = NULL;
	GtkButton* _tmp48_ = NULL;
	GtkButton* _tmp49_ = NULL;
	GtkButtonBox* button_box = NULL;
	GtkButtonBox* _tmp50_ = NULL;
	GtkButton* _tmp51_ = NULL;
	GtkBox* _tmp52_ = NULL;
	GtkWidget* _tmp53_ = NULL;
	GtkBox* _tmp54_ = NULL;
	GtkBox* _tmp55_ = NULL;
	GtkBox* _tmp56_ = NULL;
#line 56 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_val_if_fail (SPIT_DATA_IMPORTS_IS_PLUGIN_HOST (host), NULL);
#line 56 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_val_if_fail (welcome_message != NULL, NULL);
#line 56 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = (DataImportsUILibrarySelectionPane*) data_imports_ui_concrete_dialog_pane_construct (object_type);
#line 62 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = discovered_libraries;
#line 62 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1__length1 = discovered_libraries_length1;
#line 62 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp1__length1 > 0) {
#line 62 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp0_ = TRUE;
#line 760 "DataImportsUI.c"
	} else {
#line 62 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp0_ = data_imports_ui_library_selection_pane_on_file_selected != NULL;
#line 764 "DataImportsUI.c"
	}
#line 62 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_vala_assert (_tmp0_, "discovered_libraries.length > 0 || on_file_selected != null");
#line 64 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp2_ = host;
#line 64 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv->host = _tmp2_;
#line 66 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp3_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 8);
#line 66 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_ref_sink (_tmp3_);
#line 66 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	content_box = _tmp3_;
#line 67 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp4_ = content_box;
#line 67 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_set_margin_left (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_widget_get_type (), GtkWidget), 30);
#line 68 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp5_ = content_box;
#line 68 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_set_margin_right (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_widget_get_type (), GtkWidget), 30);
#line 69 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp6_ = (GtkLabel*) gtk_label_new (NULL);
#line 69 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_ref_sink (_tmp6_);
#line 69 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	welcome_label = _tmp6_;
#line 70 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp7_ = welcome_label;
#line 70 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp8_ = welcome_message;
#line 70 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_label_set_markup (_tmp7_, _tmp8_);
#line 71 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp9_ = welcome_label;
#line 71 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_label_set_line_wrap (_tmp9_, TRUE);
#line 72 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp10_ = welcome_label;
#line 72 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_set_halign (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_START);
#line 73 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp11_ = content_box;
#line 73 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp12_ = welcome_label;
#line 73 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_box_pack_start (_tmp11_, G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_widget_get_type (), GtkWidget), TRUE, TRUE, (guint) 6);
#line 76 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	radio_margin_left = 20;
#line 77 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	radio_margin_right = 20;
#line 78 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp13_ = radio_margin_left;
#line 78 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	chooser_margin_left = _tmp13_;
#line 79 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp14_ = radio_margin_right;
#line 79 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	chooser_margin_right = _tmp14_;
#line 81 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	lib_radio = NULL;
#line 82 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp15_ = discovered_libraries;
#line 82 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp15__length1 = discovered_libraries_length1;
#line 82 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp15__length1 > 0) {
#line 832 "DataImportsUI.c"
		gint _tmp16_ = 0;
		SpitDataImportsImportableLibrary** _tmp17_ = NULL;
		gint _tmp17__length1 = 0;
		const gchar* _tmp28_ = NULL;
#line 83 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp16_ = radio_margin_left;
#line 83 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		chooser_margin_left = _tmp16_ + 20;
#line 84 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp17_ = discovered_libraries;
#line 84 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp17__length1 = discovered_libraries_length1;
#line 845 "DataImportsUI.c"
		{
			SpitDataImportsImportableLibrary** library_collection = NULL;
			gint library_collection_length1 = 0;
			gint _library_collection_size_ = 0;
			gint library_it = 0;
#line 84 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			library_collection = _tmp17_;
#line 84 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			library_collection_length1 = _tmp17__length1;
#line 84 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			for (library_it = 0; library_it < _tmp17__length1; library_it = library_it + 1) {
#line 857 "DataImportsUI.c"
				SpitDataImportsImportableLibrary* _tmp18_ = NULL;
				SpitDataImportsImportableLibrary* library = NULL;
#line 84 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
				_tmp18_ = _g_object_ref0 (library_collection[library_it]);
#line 84 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
				library = _tmp18_;
#line 864 "DataImportsUI.c"
				{
					gchar* lib_radio_label = NULL;
					SpitDataImportsImportableLibrary* _tmp19_ = NULL;
					gchar* _tmp20_ = NULL;
					GtkBox* _tmp21_ = NULL;
					GtkRadioButton* _tmp22_ = NULL;
					SpitDataImportsImportableLibrary* _tmp23_ = NULL;
					const gchar* _tmp24_ = NULL;
					gint _tmp25_ = 0;
					gint _tmp26_ = 0;
					GtkRadioButton* _tmp27_ = NULL;
#line 85 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp19_ = library;
#line 85 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp20_ = spit_data_imports_importable_library_get_display_name (_tmp19_);
#line 85 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					lib_radio_label = _tmp20_;
#line 86 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp21_ = content_box;
#line 86 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp22_ = lib_radio;
#line 86 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp23_ = library;
#line 86 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp24_ = lib_radio_label;
#line 86 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp25_ = radio_margin_left;
#line 86 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp26_ = radio_margin_right;
#line 86 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp27_ = data_imports_ui_library_selection_pane_create_radio_button (self, _tmp21_, _tmp22_, _tmp23_, _tmp24_, _tmp25_, _tmp26_);
#line 86 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_g_object_unref0 (lib_radio);
#line 86 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					lib_radio = _tmp27_;
#line 84 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_g_free0 (lib_radio_label);
#line 84 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_g_object_unref0 (library);
#line 904 "DataImportsUI.c"
				}
			}
		}
#line 91 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp28_ = file_select_label;
#line 91 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		if (_tmp28_ != NULL) {
#line 912 "DataImportsUI.c"
			GtkBox* _tmp29_ = NULL;
			GtkRadioButton* _tmp30_ = NULL;
			const gchar* _tmp31_ = NULL;
			gint _tmp32_ = 0;
			gint _tmp33_ = 0;
			GtkRadioButton* _tmp34_ = NULL;
			GtkRadioButton* _tmp35_ = NULL;
			GtkRadioButton* _tmp36_ = NULL;
#line 92 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp29_ = content_box;
#line 92 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp30_ = lib_radio;
#line 92 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp31_ = file_select_label;
#line 92 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp32_ = radio_margin_left;
#line 92 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp33_ = radio_margin_right;
#line 92 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp34_ = data_imports_ui_library_selection_pane_create_radio_button (self, _tmp29_, _tmp30_, NULL, _tmp31_, _tmp32_, _tmp33_);
#line 92 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_g_object_unref0 (lib_radio);
#line 92 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			lib_radio = _tmp34_;
#line 96 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp35_ = lib_radio;
#line 96 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp36_ = _g_object_ref0 (_tmp35_);
#line 96 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_g_object_unref0 (self->priv->file_radio);
#line 96 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			self->priv->file_radio = _tmp36_;
#line 945 "DataImportsUI.c"
		}
	}
#line 99 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp37_ = file_select_label;
#line 99 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp37_ != NULL) {
#line 952 "DataImportsUI.c"
		Block10Data* _data10_;
		const gchar* _tmp38_ = NULL;
		GtkFileChooserButton* _tmp39_ = NULL;
		GtkFileChooserButton* _tmp40_ = NULL;
		GtkFileChooserButton* _tmp41_ = NULL;
		gint _tmp42_ = 0;
		GtkFileChooserButton* _tmp43_ = NULL;
		gint _tmp44_ = 0;
		GtkBox* _tmp45_ = NULL;
		GtkFileChooserButton* _tmp46_ = NULL;
#line 99 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_data10_ = g_slice_new0 (Block10Data);
#line 99 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_data10_->_ref_count_ = 1;
#line 99 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_data10_->self = g_object_ref (self);
#line 100 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp38_ = _ ("Database file:");
#line 100 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp39_ = (GtkFileChooserButton*) gtk_file_chooser_button_new (_tmp38_, GTK_FILE_CHOOSER_ACTION_OPEN);
#line 100 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		g_object_ref_sink (_tmp39_);
#line 100 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_data10_->file_chooser = _tmp39_;
#line 101 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp40_ = _data10_->file_chooser;
#line 101 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		g_signal_connect_data (G_TYPE_CHECK_INSTANCE_CAST (_tmp40_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), "selection-changed", (GCallback) ____lambda19__gtk_file_chooser_selection_changed, block10_data_ref (_data10_), (GClosureNotify) block10_data_unref, 0);
#line 107 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp41_ = _data10_->file_chooser;
#line 107 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp42_ = chooser_margin_left;
#line 107 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		gtk_widget_set_margin_left (G_TYPE_CHECK_INSTANCE_CAST (_tmp41_, gtk_widget_get_type (), GtkWidget), _tmp42_);
#line 108 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp43_ = _data10_->file_chooser;
#line 108 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp44_ = chooser_margin_right;
#line 108 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		gtk_widget_set_margin_right (G_TYPE_CHECK_INSTANCE_CAST (_tmp43_, gtk_widget_get_type (), GtkWidget), _tmp44_);
#line 109 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp45_ = content_box;
#line 109 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp46_ = _data10_->file_chooser;
#line 109 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		gtk_box_pack_start (_tmp45_, G_TYPE_CHECK_INSTANCE_CAST (_tmp46_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 6);
#line 99 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		block10_data_unref (_data10_);
#line 99 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_data10_ = NULL;
#line 1003 "DataImportsUI.c"
	}
#line 112 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp47_ = _ ("_Import");
#line 112 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp48_ = (GtkButton*) gtk_button_new_with_mnemonic (_tmp47_);
#line 112 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_ref_sink (_tmp48_);
#line 112 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->import_button);
#line 112 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv->import_button = _tmp48_;
#line 113 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp49_ = self->priv->import_button;
#line 113 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_signal_connect_object (_tmp49_, "clicked", (GCallback) ___lambda20__gtk_button_clicked, self, 0);
#line 121 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp50_ = (GtkButtonBox*) gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
#line 121 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_ref_sink (_tmp50_);
#line 121 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	button_box = _tmp50_;
#line 122 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_set (button_box, "layout-style", GTK_BUTTONBOX_CENTER, NULL);
#line 123 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp51_ = self->priv->import_button;
#line 123 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (button_box, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp51_, gtk_widget_get_type (), GtkWidget));
#line 124 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp52_ = content_box;
#line 124 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_box_pack_end (_tmp52_, G_TYPE_CHECK_INSTANCE_CAST (button_box, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 6);
#line 126 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp53_ = spit_data_imports_dialog_pane_get_widget (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_DIALOG_PANE, SpitDataImportsDialogPane));
#line 126 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp54_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp53_, gtk_box_get_type ()) ? ((GtkBox*) _tmp53_) : NULL;
#line 126 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp54_ == NULL) {
#line 126 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (_tmp53_);
#line 1043 "DataImportsUI.c"
	}
#line 126 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp55_ = _tmp54_;
#line 126 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp56_ = content_box;
#line 126 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_box_pack_start (_tmp55_, G_TYPE_CHECK_INSTANCE_CAST (_tmp56_, gtk_widget_get_type (), GtkWidget), TRUE, TRUE, (guint) 0);
#line 126 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (_tmp55_);
#line 128 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_library_selection_pane_set_import_button_sensitivity (self);
#line 56 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (button_box);
#line 56 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (lib_radio);
#line 56 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (welcome_label);
#line 56 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (content_box);
#line 56 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return self;
#line 1065 "DataImportsUI.c"
}


DataImportsUILibrarySelectionPane* data_imports_ui_library_selection_pane_new (SpitDataImportsPluginHost* host, const gchar* welcome_message, SpitDataImportsImportableLibrary** discovered_libraries, int discovered_libraries_length1, const gchar* file_select_label) {
#line 56 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return data_imports_ui_library_selection_pane_construct (DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE, host, welcome_message, discovered_libraries, discovered_libraries_length1, file_select_label);
#line 1072 "DataImportsUI.c"
}


static Block11Data* block11_data_ref (Block11Data* _data11_) {
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_atomic_int_inc (&_data11_->_ref_count_);
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return _data11_;
#line 1081 "DataImportsUI.c"
}


static void block11_data_unref (void * _userdata_) {
	Block11Data* _data11_;
	_data11_ = (Block11Data*) _userdata_;
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (g_atomic_int_dec_and_test (&_data11_->_ref_count_)) {
#line 1090 "DataImportsUI.c"
		DataImportsUILibrarySelectionPane* self;
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		self = _data11_->self;
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (_data11_->button);
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (_data11_->library);
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (self);
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		g_slice_free (Block11Data, _data11_);
#line 1102 "DataImportsUI.c"
	}
}


static void __lambda18_ (Block11Data* _data11_) {
	DataImportsUILibrarySelectionPane* self;
	GtkRadioButton* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 140 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = _data11_->self;
#line 141 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = _data11_->button;
#line 141 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 141 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp2_ = _tmp1_;
#line 141 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp2_) {
#line 1122 "DataImportsUI.c"
		SpitDataImportsImportableLibrary* _tmp3_ = NULL;
		SpitDataImportsImportableLibrary* _tmp4_ = NULL;
#line 142 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp3_ = _data11_->library;
#line 142 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp4_ = _g_object_ref0 (_tmp3_);
#line 142 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (self->priv->selected_library);
#line 142 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		self->priv->selected_library = _tmp4_;
#line 143 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		data_imports_ui_library_selection_pane_set_import_button_sensitivity (self);
#line 1135 "DataImportsUI.c"
	}
}


static void ___lambda18__gtk_toggle_button_toggled (GtkToggleButton* _sender, gpointer self) {
#line 140 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	__lambda18_ (self);
#line 1143 "DataImportsUI.c"
}


static GtkRadioButton* data_imports_ui_library_selection_pane_create_radio_button (DataImportsUILibrarySelectionPane* self, GtkBox* box, GtkRadioButton* group, SpitDataImportsImportableLibrary* library, const gchar* label, gint margin_left, gint margin_right) {
	GtkRadioButton* result = NULL;
	Block11Data* _data11_;
	SpitDataImportsImportableLibrary* _tmp0_ = NULL;
	SpitDataImportsImportableLibrary* _tmp1_ = NULL;
	GtkRadioButton* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	GtkRadioButton* _tmp4_ = NULL;
	GtkRadioButton* _tmp5_ = NULL;
	GtkRadioButton* _tmp9_ = NULL;
	GtkRadioButton* _tmp10_ = NULL;
	gint _tmp11_ = 0;
	GtkRadioButton* _tmp12_ = NULL;
	gint _tmp13_ = 0;
	GtkBox* _tmp14_ = NULL;
	GtkRadioButton* _tmp15_ = NULL;
	GtkRadioButton* _tmp16_ = NULL;
	GtkRadioButton* _tmp17_ = NULL;
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_val_if_fail (DATA_IMPORTS_UI_IS_LIBRARY_SELECTION_PANE (self), NULL);
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_val_if_fail (GTK_IS_BOX (box), NULL);
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_val_if_fail ((group == NULL) || GTK_IS_RADIO_BUTTON (group), NULL);
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_val_if_fail ((library == NULL) || SPIT_DATA_IMPORTS_IS_IMPORTABLE_LIBRARY (library), NULL);
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_val_if_fail (label != NULL, NULL);
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_data11_ = g_slice_new0 (Block11Data);
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_data11_->_ref_count_ = 1;
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_data11_->self = g_object_ref (self);
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = library;
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (_data11_->library);
#line 131 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_data11_->library = _tmp1_;
#line 135 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp2_ = group;
#line 135 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp3_ = label;
#line 135 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp4_ = (GtkRadioButton*) gtk_radio_button_new_with_label_from_widget (_tmp2_, _tmp3_);
#line 135 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_ref_sink (_tmp4_);
#line 135 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_data11_->button = _tmp4_;
#line 136 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp5_ = group;
#line 136 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp5_ == NULL) {
#line 1203 "DataImportsUI.c"
		GtkRadioButton* _tmp6_ = NULL;
		SpitDataImportsImportableLibrary* _tmp7_ = NULL;
		SpitDataImportsImportableLibrary* _tmp8_ = NULL;
#line 137 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp6_ = _data11_->button;
#line 137 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_toggle_button_get_type (), GtkToggleButton), TRUE);
#line 138 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp7_ = _data11_->library;
#line 138 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp8_ = _g_object_ref0 (_tmp7_);
#line 138 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (self->priv->selected_library);
#line 138 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		self->priv->selected_library = _tmp8_;
#line 1219 "DataImportsUI.c"
	}
#line 140 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp9_ = _data11_->button;
#line 140 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_signal_connect_data (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_toggle_button_get_type (), GtkToggleButton), "toggled", (GCallback) ___lambda18__gtk_toggle_button_toggled, block11_data_ref (_data11_), (GClosureNotify) block11_data_unref, 0);
#line 147 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp10_ = _data11_->button;
#line 147 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp11_ = margin_left;
#line 147 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_set_margin_left (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_widget_get_type (), GtkWidget), _tmp11_);
#line 148 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp12_ = _data11_->button;
#line 148 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp13_ = margin_right;
#line 148 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_set_margin_right (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_widget_get_type (), GtkWidget), _tmp13_);
#line 149 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp14_ = box;
#line 149 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp15_ = _data11_->button;
#line 149 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_box_pack_start (_tmp14_, G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 6);
#line 150 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp16_ = _data11_->button;
#line 150 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp17_ = _g_object_ref0 (_tmp16_);
#line 150 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	result = _tmp17_;
#line 150 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	block11_data_unref (_data11_);
#line 150 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_data11_ = NULL;
#line 150 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return result;
#line 1255 "DataImportsUI.c"
}


static void data_imports_ui_library_selection_pane_set_import_button_sensitivity (DataImportsUILibrarySelectionPane* self) {
	gboolean _tmp0_ = FALSE;
	SpitDataImportsImportableLibrary* _tmp1_ = NULL;
	GtkButton* _tmp3_ = NULL;
#line 153 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_LIBRARY_SELECTION_PANE (self));
#line 154 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = self->priv->selected_library;
#line 154 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp1_ != NULL) {
#line 154 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp0_ = TRUE;
#line 1271 "DataImportsUI.c"
	} else {
		GFile* _tmp2_ = NULL;
#line 154 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp2_ = self->priv->selected_file;
#line 154 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp0_ = _tmp2_ != NULL;
#line 1278 "DataImportsUI.c"
	}
#line 154 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp3_ = self->priv->import_button;
#line 154 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_widget_get_type (), GtkWidget), _tmp0_);
#line 1284 "DataImportsUI.c"
}


static void data_imports_ui_library_selection_pane_on_library_selected (DataImportsUILibrarySelectionPane* self, SpitDataImportsImportableLibrary* library) {
	SpitDataImportsPluginHost* _tmp0_ = NULL;
	SpitDataImportsDataImporter* _tmp1_ = NULL;
	SpitDataImportsDataImporter* _tmp2_ = NULL;
	SpitDataImportsImportableLibrary* _tmp3_ = NULL;
#line 157 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_LIBRARY_SELECTION_PANE (self));
#line 157 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (SPIT_DATA_IMPORTS_IS_IMPORTABLE_LIBRARY (library));
#line 158 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->host;
#line 158 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = spit_data_imports_plugin_host_get_data_importer (_tmp0_);
#line 158 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp2_ = _tmp1_;
#line 158 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp3_ = library;
#line 158 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	spit_data_imports_data_importer_on_library_selected (_tmp2_, _tmp3_);
#line 158 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (_tmp2_);
#line 1309 "DataImportsUI.c"
}


static void data_imports_ui_library_selection_pane_on_file_selected (DataImportsUILibrarySelectionPane* self, GFile* file) {
	SpitDataImportsPluginHost* _tmp0_ = NULL;
	SpitDataImportsDataImporter* _tmp1_ = NULL;
	SpitDataImportsDataImporter* _tmp2_ = NULL;
	GFile* _tmp3_ = NULL;
#line 161 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_LIBRARY_SELECTION_PANE (self));
#line 161 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (G_IS_FILE (file));
#line 162 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->host;
#line 162 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = spit_data_imports_plugin_host_get_data_importer (_tmp0_);
#line 162 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp2_ = _tmp1_;
#line 162 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp3_ = file;
#line 162 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	spit_data_imports_data_importer_on_file_selected (_tmp2_, _tmp3_);
#line 162 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (_tmp2_);
#line 1334 "DataImportsUI.c"
}


static void data_imports_ui_library_selection_pane_class_init (DataImportsUILibrarySelectionPaneClass * klass) {
#line 49 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_library_selection_pane_parent_class = g_type_class_peek_parent (klass);
#line 49 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_type_class_add_private (klass, sizeof (DataImportsUILibrarySelectionPanePrivate));
#line 49 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	G_OBJECT_CLASS (klass)->finalize = data_imports_ui_library_selection_pane_finalize;
#line 1345 "DataImportsUI.c"
}


static void data_imports_ui_library_selection_pane_instance_init (DataImportsUILibrarySelectionPane * self) {
#line 49 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv = DATA_IMPORTS_UI_LIBRARY_SELECTION_PANE_GET_PRIVATE (self);
#line 51 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv->selected_library = NULL;
#line 52 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv->selected_file = NULL;
#line 54 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv->file_radio = NULL;
#line 1358 "DataImportsUI.c"
}


static void data_imports_ui_library_selection_pane_finalize (GObject* obj) {
	DataImportsUILibrarySelectionPane * self;
#line 49 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE, DataImportsUILibrarySelectionPane);
#line 51 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->selected_library);
#line 52 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->selected_file);
#line 53 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->import_button);
#line 54 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->file_radio);
#line 49 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	G_OBJECT_CLASS (data_imports_ui_library_selection_pane_parent_class)->finalize (obj);
#line 1376 "DataImportsUI.c"
}


GType data_imports_ui_library_selection_pane_get_type (void) {
	static volatile gsize data_imports_ui_library_selection_pane_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_ui_library_selection_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsUILibrarySelectionPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_ui_library_selection_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsUILibrarySelectionPane), 0, (GInstanceInitFunc) data_imports_ui_library_selection_pane_instance_init, NULL };
		GType data_imports_ui_library_selection_pane_type_id;
		data_imports_ui_library_selection_pane_type_id = g_type_register_static (DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, "DataImportsUILibrarySelectionPane", &g_define_type_info, 0);
		g_once_init_leave (&data_imports_ui_library_selection_pane_type_id__volatile, data_imports_ui_library_selection_pane_type_id);
	}
	return data_imports_ui_library_selection_pane_type_id__volatile;
}


DataImportsUIProgressPane* data_imports_ui_progress_pane_construct (GType object_type, const gchar* message) {
	DataImportsUIProgressPane * self = NULL;
	GtkBox* content_box = NULL;
	GtkBox* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GtkLabel* _tmp2_ = NULL;
	GtkLabel* _tmp3_ = NULL;
	GtkProgressBar* _tmp4_ = NULL;
	GtkProgressBar* _tmp5_ = NULL;
	GtkLabel* _tmp6_ = NULL;
	GtkLabel* _tmp7_ = NULL;
	GtkWidget* _tmp8_ = NULL;
	GtkContainer* _tmp9_ = NULL;
	GtkContainer* _tmp10_ = NULL;
#line 171 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_val_if_fail (message != NULL, NULL);
#line 171 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = (DataImportsUIProgressPane*) data_imports_ui_concrete_dialog_pane_construct (object_type);
#line 172 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 8);
#line 172 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_ref_sink (_tmp0_);
#line 172 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	content_box = _tmp0_;
#line 173 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = message;
#line 173 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp2_ = (GtkLabel*) gtk_label_new (_tmp1_);
#line 173 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_ref_sink (_tmp2_);
#line 173 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->message_label);
#line 173 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv->message_label = _tmp2_;
#line 174 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp3_ = self->priv->message_label;
#line 174 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_box_pack_start (content_box, G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_widget_get_type (), GtkWidget), TRUE, TRUE, (guint) 6);
#line 175 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp4_ = (GtkProgressBar*) gtk_progress_bar_new ();
#line 175 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_ref_sink (_tmp4_);
#line 175 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->progress_bar);
#line 175 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv->progress_bar = _tmp4_;
#line 176 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp5_ = self->priv->progress_bar;
#line 176 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_box_pack_start (content_box, G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_widget_get_type (), GtkWidget), FALSE, TRUE, (guint) 6);
#line 177 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp6_ = (GtkLabel*) gtk_label_new ("");
#line 177 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_ref_sink (_tmp6_);
#line 177 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->progress_label);
#line 177 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv->progress_label = _tmp6_;
#line 178 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp7_ = self->priv->progress_label;
#line 178 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_box_pack_start (content_box, G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_widget_get_type (), GtkWidget), FALSE, TRUE, (guint) 6);
#line 180 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp8_ = spit_data_imports_dialog_pane_get_widget (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_DIALOG_PANE, SpitDataImportsDialogPane));
#line 180 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp9_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, gtk_container_get_type ()) ? ((GtkContainer*) _tmp8_) : NULL;
#line 180 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp9_ == NULL) {
#line 180 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (_tmp8_);
#line 1462 "DataImportsUI.c"
	}
#line 180 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp10_ = _tmp9_;
#line 180 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_container_add (_tmp10_, G_TYPE_CHECK_INSTANCE_CAST (content_box, gtk_widget_get_type (), GtkWidget));
#line 180 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (_tmp10_);
#line 171 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (content_box);
#line 171 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return self;
#line 1474 "DataImportsUI.c"
}


DataImportsUIProgressPane* data_imports_ui_progress_pane_new (const gchar* message) {
#line 171 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return data_imports_ui_progress_pane_construct (DATA_IMPORTS_UI_TYPE_PROGRESS_PANE, message);
#line 1481 "DataImportsUI.c"
}


void data_imports_ui_progress_pane_update_progress (DataImportsUIProgressPane* self, gdouble progress, const gchar* progress_message) {
	GtkProgressBar* _tmp0_ = NULL;
	gdouble _tmp1_ = 0.0;
	const gchar* _tmp2_ = NULL;
#line 183 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_PROGRESS_PANE (self));
#line 184 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->progress_bar;
#line 184 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = progress;
#line 184 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_progress_bar_set_fraction (_tmp0_, _tmp1_);
#line 185 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp2_ = progress_message;
#line 185 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp2_ != NULL) {
#line 1501 "DataImportsUI.c"
		GtkLabel* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
#line 186 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp3_ = self->priv->progress_label;
#line 186 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp4_ = progress_message;
#line 186 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		gtk_label_set_label (_tmp3_, _tmp4_);
#line 1510 "DataImportsUI.c"
	}
#line 187 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	spin_event_loop ();
#line 1514 "DataImportsUI.c"
}


static void data_imports_ui_progress_pane_class_init (DataImportsUIProgressPaneClass * klass) {
#line 166 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_progress_pane_parent_class = g_type_class_peek_parent (klass);
#line 166 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_type_class_add_private (klass, sizeof (DataImportsUIProgressPanePrivate));
#line 166 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	G_OBJECT_CLASS (klass)->finalize = data_imports_ui_progress_pane_finalize;
#line 1525 "DataImportsUI.c"
}


static void data_imports_ui_progress_pane_instance_init (DataImportsUIProgressPane * self) {
#line 166 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv = DATA_IMPORTS_UI_PROGRESS_PANE_GET_PRIVATE (self);
#line 1532 "DataImportsUI.c"
}


static void data_imports_ui_progress_pane_finalize (GObject* obj) {
	DataImportsUIProgressPane * self;
#line 166 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DATA_IMPORTS_UI_TYPE_PROGRESS_PANE, DataImportsUIProgressPane);
#line 167 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->message_label);
#line 168 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->progress_label);
#line 169 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->progress_bar);
#line 166 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	G_OBJECT_CLASS (data_imports_ui_progress_pane_parent_class)->finalize (obj);
#line 1548 "DataImportsUI.c"
}


GType data_imports_ui_progress_pane_get_type (void) {
	static volatile gsize data_imports_ui_progress_pane_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_ui_progress_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsUIProgressPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_ui_progress_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsUIProgressPane), 0, (GInstanceInitFunc) data_imports_ui_progress_pane_instance_init, NULL };
		GType data_imports_ui_progress_pane_type_id;
		data_imports_ui_progress_pane_type_id = g_type_register_static (DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, "DataImportsUIProgressPane", &g_define_type_info, 0);
		g_once_init_leave (&data_imports_ui_progress_pane_type_id__volatile, data_imports_ui_progress_pane_type_id);
	}
	return data_imports_ui_progress_pane_type_id__volatile;
}


static gboolean _data_imports_ui_data_imports_dialog_on_window_close_gtk_widget_delete_event (GtkWidget* _sender, GdkEventAny* event, gpointer self) {
	gboolean result;
	result = data_imports_ui_data_imports_dialog_on_window_close ((DataImportsUIDataImportsDialog*) self, event);
#line 218 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return result;
#line 1569 "DataImportsUI.c"
}


static void _data_imports_ui_data_imports_dialog_on_service_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self) {
#line 251 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_data_imports_dialog_on_service_changed ((DataImportsUIDataImportsDialog*) self);
#line 1576 "DataImportsUI.c"
}


static void _data_imports_ui_data_imports_dialog_on_close_cancel_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 291 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_data_imports_dialog_on_close_cancel_clicked ((DataImportsUIDataImportsDialog*) self);
#line 1583 "DataImportsUI.c"
}


DataImportsUIDataImportsDialog* data_imports_ui_data_imports_dialog_construct (GType object_type) {
	DataImportsUIDataImportsDialog * self = NULL;
	gboolean use_header = FALSE;
	GtkSettings* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	gchar* title = NULL;
	const gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* label = NULL;
	const gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	SpitDataImportsService** loaded_services = NULL;
	gint _tmp10_ = 0;
	SpitDataImportsService** _tmp11_ = NULL;
	gint loaded_services_length1 = 0;
	gint _loaded_services_size_ = 0;
	SpitDataImportsService** _tmp12_ = NULL;
	gint _tmp12__length1 = 0;
	GtkBox* _tmp64_ = NULL;
	GtkBox* _tmp65_ = NULL;
	GtkBox* _tmp66_ = NULL;
	GtkButton* _tmp67_ = NULL;
	GtkButton* _tmp68_ = NULL;
	GtkButton* _tmp69_ = NULL;
	gboolean _tmp70_ = FALSE;
	SpitDataImportsService** _tmp77_ = NULL;
	gint _tmp77__length1 = 0;
#line 212 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = gtk_settings_get_default ();
#line 212 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, G_TYPE_OBJECT, GObject), "gtk-dialogs-use-header", &use_header, NULL);
#line 213 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp2_ = use_header;
#line 213 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp2_) {
#line 213 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp1_ = 1;
#line 1627 "DataImportsUI.c"
	} else {
#line 213 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp1_ = 0;
#line 1631 "DataImportsUI.c"
	}
#line 213 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = (DataImportsUIDataImportsDialog*) g_object_new (object_type, "use-header-bar", _tmp1_, NULL);
#line 214 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp3_ = use_header;
#line 214 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp3_) {
#line 1639 "DataImportsUI.c"
		GtkWidget* _tmp4_ = NULL;
#line 215 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp4_ = gtk_dialog_get_header_bar (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 215 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		gtk_header_bar_set_show_close_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_header_bar_get_type (), GtkHeaderBar), FALSE);
#line 1645 "DataImportsUI.c"
	}
#line 217 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), FALSE);
#line 218 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), "delete-event", (GCallback) _data_imports_ui_data_imports_dialog_on_window_close_gtk_widget_delete_event, self, 0);
#line 220 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp5_ = _ ("Import From Application");
#line 220 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp6_ = g_strdup (_tmp5_);
#line 220 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	title = _tmp6_;
#line 221 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp7_ = _ ("Import media _from:");
#line 221 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp8_ = g_strdup (_tmp7_);
#line 221 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	label = _tmp8_;
#line 223 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp9_ = title;
#line 223 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), _tmp9_);
#line 225 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp11_ = spit_data_imports_load_services (FALSE, &_tmp10_);
#line 225 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	loaded_services = _tmp11_;
#line 225 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	loaded_services_length1 = _tmp10_;
#line 225 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_loaded_services_size_ = loaded_services_length1;
#line 227 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp12_ = loaded_services;
#line 227 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp12__length1 = loaded_services_length1;
#line 227 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp12__length1 > 0) {
#line 1681 "DataImportsUI.c"
		GtkComboBoxText* _tmp13_ = NULL;
		GtkComboBoxText* _tmp14_ = NULL;
		gchar* last_used_service = NULL;
		ConfigFacade* _tmp15_ = NULL;
		ConfigFacade* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		gint ticker = 0;
		gint last_used_index = 0;
		SpitDataImportsService** _tmp19_ = NULL;
		gint _tmp19__length1 = 0;
		gint _tmp33_ = 0;
		GtkComboBoxText* _tmp37_ = NULL;
		gboolean _tmp38_ = FALSE;
#line 230 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp13_ = (GtkComboBoxText*) gtk_combo_box_text_new ();
#line 230 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		g_object_ref_sink (_tmp13_);
#line 230 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (self->priv->service_selector_box);
#line 230 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		self->priv->service_selector_box = _tmp13_;
#line 231 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp14_ = self->priv->service_selector_box;
#line 231 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, gtk_combo_box_get_type (), GtkComboBox), 0);
#line 234 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp15_ = config_facade_get_instance ();
#line 234 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp16_ = _tmp15_;
#line 234 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp17_ = configuration_facade_get_last_used_dataimports_service (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 234 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp18_ = _tmp17_;
#line 234 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (_tmp16_);
#line 234 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		last_used_service = _tmp18_;
#line 236 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		ticker = 0;
#line 237 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		last_used_index = -1;
#line 238 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp19_ = loaded_services;
#line 238 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp19__length1 = loaded_services_length1;
#line 1728 "DataImportsUI.c"
		{
			SpitDataImportsService** service_collection = NULL;
			gint service_collection_length1 = 0;
			gint _service_collection_size_ = 0;
			gint service_it = 0;
#line 238 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			service_collection = _tmp19_;
#line 238 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			service_collection_length1 = _tmp19__length1;
#line 238 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			for (service_it = 0; service_it < _tmp19__length1; service_it = service_it + 1) {
#line 1740 "DataImportsUI.c"
				SpitDataImportsService* _tmp20_ = NULL;
				SpitDataImportsService* service = NULL;
#line 238 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
				_tmp20_ = _g_object_ref0 (service_collection[service_it]);
#line 238 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
				service = _tmp20_;
#line 1747 "DataImportsUI.c"
				{
					gchar* curr_service_id = NULL;
					SpitDataImportsService* _tmp21_ = NULL;
					const gchar* _tmp22_ = NULL;
					gchar* _tmp23_ = NULL;
					gboolean _tmp24_ = FALSE;
					const gchar* _tmp25_ = NULL;
					GtkComboBoxText* _tmp29_ = NULL;
					SpitDataImportsService* _tmp30_ = NULL;
					const gchar* _tmp31_ = NULL;
					gint _tmp32_ = 0;
#line 239 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp21_ = service;
#line 239 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp22_ = spit_pluggable_get_id (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 239 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp23_ = g_strdup (_tmp22_);
#line 239 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					curr_service_id = _tmp23_;
#line 240 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp25_ = last_used_service;
#line 240 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					if (_tmp25_ != NULL) {
#line 1771 "DataImportsUI.c"
						const gchar* _tmp26_ = NULL;
						const gchar* _tmp27_ = NULL;
#line 240 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
						_tmp26_ = last_used_service;
#line 240 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
						_tmp27_ = curr_service_id;
#line 240 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
						_tmp24_ = g_strcmp0 (_tmp26_, _tmp27_) == 0;
#line 1780 "DataImportsUI.c"
					} else {
#line 240 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
						_tmp24_ = FALSE;
#line 1784 "DataImportsUI.c"
					}
#line 240 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					if (_tmp24_) {
#line 1788 "DataImportsUI.c"
						gint _tmp28_ = 0;
#line 241 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
						_tmp28_ = ticker;
#line 241 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
						last_used_index = _tmp28_;
#line 1794 "DataImportsUI.c"
					}
#line 243 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp29_ = self->priv->service_selector_box;
#line 243 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp30_ = service;
#line 243 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp31_ = spit_pluggable_get_pluggable_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp30_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 243 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					gtk_combo_box_text_append_text (_tmp29_, _tmp31_);
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp32_ = ticker;
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					ticker = _tmp32_ + 1;
#line 238 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_g_free0 (curr_service_id);
#line 238 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_g_object_unref0 (service);
#line 1812 "DataImportsUI.c"
				}
			}
		}
#line 246 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp33_ = last_used_index;
#line 246 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		if (_tmp33_ >= 0) {
#line 1820 "DataImportsUI.c"
			GtkComboBoxText* _tmp34_ = NULL;
			gint _tmp35_ = 0;
#line 247 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp34_ = self->priv->service_selector_box;
#line 247 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp35_ = last_used_index;
#line 247 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp34_, gtk_combo_box_get_type (), GtkComboBox), _tmp35_);
#line 1829 "DataImportsUI.c"
		} else {
			GtkComboBoxText* _tmp36_ = NULL;
#line 249 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp36_ = self->priv->service_selector_box;
#line 249 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp36_, gtk_combo_box_get_type (), GtkComboBox), 0);
#line 1836 "DataImportsUI.c"
		}
#line 251 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp37_ = self->priv->service_selector_box;
#line 251 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp37_, gtk_combo_box_get_type (), GtkComboBox), "changed", (GCallback) _data_imports_ui_data_imports_dialog_on_service_changed_gtk_combo_box_changed, self, 0);
#line 253 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp38_ = use_header;
#line 253 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		if (!_tmp38_) {
#line 1846 "DataImportsUI.c"
			GtkLabel* service_selector_box_label = NULL;
			const gchar* _tmp39_ = NULL;
			GtkLabel* _tmp40_ = NULL;
			GtkLabel* _tmp41_ = NULL;
			GtkComboBoxText* _tmp42_ = NULL;
			GtkLabel* _tmp43_ = NULL;
			GtkAlignment* service_selector_box_wrapper = NULL;
			GtkAlignment* _tmp44_ = NULL;
			GtkAlignment* _tmp45_ = NULL;
			GtkComboBoxText* _tmp46_ = NULL;
			GtkBox* service_selector_layouter = NULL;
			GtkBox* _tmp47_ = NULL;
			GtkBox* _tmp48_ = NULL;
			GtkBox* _tmp49_ = NULL;
			GtkLabel* _tmp50_ = NULL;
			GtkBox* _tmp51_ = NULL;
			GtkAlignment* _tmp52_ = NULL;
			GtkBox* service_area_layouter = NULL;
			GtkBox* _tmp53_ = NULL;
			GtkBox* _tmp54_ = NULL;
			GtkBox* _tmp55_ = NULL;
			GtkSeparator* service_central_separator = NULL;
			GtkSeparator* _tmp56_ = NULL;
			GtkBox* _tmp57_ = NULL;
			GtkSeparator* _tmp58_ = NULL;
			GtkAlignment* service_area_wrapper = NULL;
			GtkAlignment* _tmp59_ = NULL;
			GtkAlignment* _tmp60_ = NULL;
			GtkBox* _tmp61_ = NULL;
			GtkBox* _tmp62_ = NULL;
			GtkAlignment* _tmp63_ = NULL;
#line 255 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp39_ = label;
#line 255 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp40_ = (GtkLabel*) gtk_label_new_with_mnemonic (_tmp39_);
#line 255 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			g_object_ref_sink (_tmp40_);
#line 255 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			service_selector_box_label = _tmp40_;
#line 256 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp41_ = service_selector_box_label;
#line 256 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp42_ = self->priv->service_selector_box;
#line 256 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_label_set_mnemonic_widget (_tmp41_, G_TYPE_CHECK_INSTANCE_CAST (_tmp42_, gtk_widget_get_type (), GtkWidget));
#line 257 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp43_ = service_selector_box_label;
#line 257 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_misc_set_alignment (G_TYPE_CHECK_INSTANCE_CAST (_tmp43_, gtk_misc_get_type (), GtkMisc), 0.0f, 0.5f);
#line 263 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp44_ = (GtkAlignment*) gtk_alignment_new (1.0f, 0.5f, 0.0f, 0.0f);
#line 263 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			g_object_ref_sink (_tmp44_);
#line 263 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			service_selector_box_wrapper = _tmp44_;
#line 264 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp45_ = service_selector_box_wrapper;
#line 264 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp46_ = self->priv->service_selector_box;
#line 264 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp45_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp46_, gtk_widget_get_type (), GtkWidget));
#line 266 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp47_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8);
#line 266 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			g_object_ref_sink (_tmp47_);
#line 266 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			service_selector_layouter = _tmp47_;
#line 267 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp48_ = service_selector_layouter;
#line 267 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_container_set_border_width (G_TYPE_CHECK_INSTANCE_CAST (_tmp48_, gtk_container_get_type (), GtkContainer), (guint) 12);
#line 268 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp49_ = service_selector_layouter;
#line 268 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp50_ = service_selector_box_label;
#line 268 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp49_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp50_, gtk_widget_get_type (), GtkWidget));
#line 269 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp51_ = service_selector_layouter;
#line 269 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp52_ = service_selector_box_wrapper;
#line 269 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_box_pack_start (_tmp51_, G_TYPE_CHECK_INSTANCE_CAST (_tmp52_, gtk_widget_get_type (), GtkWidget), TRUE, TRUE, (guint) 0);
#line 273 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp53_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 273 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			g_object_ref_sink (_tmp53_);
#line 273 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			service_area_layouter = _tmp53_;
#line 274 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp54_ = service_area_layouter;
#line 274 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp55_ = service_selector_layouter;
#line 274 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_box_pack_start (_tmp54_, G_TYPE_CHECK_INSTANCE_CAST (_tmp55_, gtk_widget_get_type (), GtkWidget), TRUE, TRUE, (guint) 0);
#line 275 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp56_ = (GtkSeparator*) gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
#line 275 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			g_object_ref_sink (_tmp56_);
#line 275 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			service_central_separator = _tmp56_;
#line 276 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp57_ = service_area_layouter;
#line 276 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp58_ = service_central_separator;
#line 276 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp57_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp58_, gtk_widget_get_type (), GtkWidget));
#line 278 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp59_ = (GtkAlignment*) gtk_alignment_new (0.0f, 0.0f, 1.0f, 0.0f);
#line 278 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			g_object_ref_sink (_tmp59_);
#line 278 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			service_area_wrapper = _tmp59_;
#line 279 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp60_ = service_area_wrapper;
#line 279 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp61_ = service_area_layouter;
#line 279 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp60_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp61_, gtk_widget_get_type (), GtkWidget));
#line 281 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp62_ = (GtkBox*) gtk_dialog_get_content_area (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 281 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp63_ = service_area_wrapper;
#line 281 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			gtk_box_pack_start (G_TYPE_CHECK_INSTANCE_CAST (_tmp62_, gtk_box_get_type (), GtkBox), G_TYPE_CHECK_INSTANCE_CAST (_tmp63_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 253 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_g_object_unref0 (service_area_wrapper);
#line 253 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_g_object_unref0 (service_central_separator);
#line 253 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_g_object_unref0 (service_area_layouter);
#line 253 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_g_object_unref0 (service_selector_layouter);
#line 253 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_g_object_unref0 (service_selector_box_wrapper);
#line 253 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_g_object_unref0 (service_selector_box_label);
#line 1984 "DataImportsUI.c"
		}
#line 227 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_free0 (last_used_service);
#line 1988 "DataImportsUI.c"
	}
#line 286 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp64_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 286 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_ref_sink (_tmp64_);
#line 286 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->central_area_layouter);
#line 286 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv->central_area_layouter = _tmp64_;
#line 287 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp65_ = (GtkBox*) gtk_dialog_get_content_area (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 287 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp66_ = self->priv->central_area_layouter;
#line 287 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_box_pack_start (G_TYPE_CHECK_INSTANCE_CAST (_tmp65_, gtk_box_get_type (), GtkBox), G_TYPE_CHECK_INSTANCE_CAST (_tmp66_, gtk_widget_get_type (), GtkWidget), TRUE, TRUE, (guint) 0);
#line 289 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp67_ = (GtkButton*) gtk_button_new_with_mnemonic ("_Cancel");
#line 289 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_object_ref_sink (_tmp67_);
#line 289 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->close_cancel_button);
#line 289 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv->close_cancel_button = _tmp67_;
#line 290 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp68_ = self->priv->close_cancel_button;
#line 290 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_set_can_default (G_TYPE_CHECK_INSTANCE_CAST (_tmp68_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 291 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp69_ = self->priv->close_cancel_button;
#line 291 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_signal_connect_object (_tmp69_, "clicked", (GCallback) _data_imports_ui_data_imports_dialog_on_close_cancel_clicked_gtk_button_clicked, self, 0);
#line 293 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp70_ = use_header;
#line 293 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp70_) {
#line 2024 "DataImportsUI.c"
		GtkWidget* _tmp71_ = NULL;
		GtkButton* _tmp72_ = NULL;
		GtkWidget* _tmp73_ = NULL;
		GtkComboBoxText* _tmp74_ = NULL;
#line 294 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp71_ = gtk_dialog_get_header_bar (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 294 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp72_ = self->priv->close_cancel_button;
#line 294 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		gtk_header_bar_pack_start (G_TYPE_CHECK_INSTANCE_CAST (_tmp71_, gtk_header_bar_get_type (), GtkHeaderBar), G_TYPE_CHECK_INSTANCE_CAST (_tmp72_, gtk_widget_get_type (), GtkWidget));
#line 295 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp73_ = gtk_dialog_get_header_bar (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 295 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp74_ = self->priv->service_selector_box;
#line 295 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		gtk_header_bar_pack_end (G_TYPE_CHECK_INSTANCE_CAST (_tmp73_, gtk_header_bar_get_type (), GtkHeaderBar), G_TYPE_CHECK_INSTANCE_CAST (_tmp74_, gtk_widget_get_type (), GtkWidget));
#line 2041 "DataImportsUI.c"
	} else {
		GtkWidget* _tmp75_ = NULL;
		GtkButton* _tmp76_ = NULL;
#line 298 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp75_ = gtk_dialog_get_action_area (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 298 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp76_ = self->priv->close_cancel_button;
#line 298 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (_tmp75_, gtk_box_get_type (), GtkBox), gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp76_, gtk_widget_get_type (), GtkWidget));
#line 2051 "DataImportsUI.c"
	}
#line 300 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_data_imports_dialog_set_standard_window_mode (self);
#line 302 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp77_ = loaded_services;
#line 302 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp77__length1 = loaded_services_length1;
#line 302 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp77__length1 > 0) {
#line 304 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		data_imports_ui_data_imports_dialog_on_service_changed (self);
#line 2063 "DataImportsUI.c"
	} else {
		DataImportsUIStaticMessagePane* _tmp78_ = NULL;
		DataImportsUIStaticMessagePane* _tmp79_ = NULL;
#line 307 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp78_ = data_imports_ui_static_message_pane_new_with_pango (DATA_IMPORTS_UI_NO_PLUGINS_ENABLED_MESSAGE);
#line 307 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp79_ = _tmp78_;
#line 307 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		data_imports_ui_data_imports_dialog_install_pane (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp79_, SPIT_DATA_IMPORTS_TYPE_DIALOG_PANE, SpitDataImportsDialogPane));
#line 307 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (_tmp79_);
#line 308 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		data_imports_ui_data_imports_dialog_set_close_button_mode (self);
#line 2077 "DataImportsUI.c"
	}
#line 311 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 210 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	loaded_services = (_vala_array_free (loaded_services, loaded_services_length1, (GDestroyNotify) g_object_unref), NULL);
#line 210 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_free0 (label);
#line 210 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_free0 (title);
#line 210 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return self;
#line 2089 "DataImportsUI.c"
}


DataImportsUIDataImportsDialog* data_imports_ui_data_imports_dialog_new (void) {
#line 210 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return data_imports_ui_data_imports_dialog_construct (DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG);
#line 2096 "DataImportsUI.c"
}


DataImportsUIDataImportsDialog* data_imports_ui_data_imports_dialog_get_or_create_instance (void) {
	DataImportsUIDataImportsDialog* result = NULL;
	DataImportsUIDataImportsDialog* _tmp0_ = NULL;
	DataImportsUIDataImportsDialog* _tmp2_ = NULL;
	DataImportsUIDataImportsDialog* _tmp3_ = NULL;
#line 315 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = data_imports_ui_data_imports_dialog_instance;
#line 315 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp0_ == NULL) {
#line 2109 "DataImportsUI.c"
		DataImportsUIDataImportsDialog* _tmp1_ = NULL;
#line 316 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp1_ = data_imports_ui_data_imports_dialog_new ();
#line 316 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		g_object_ref_sink (_tmp1_);
#line 316 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (data_imports_ui_data_imports_dialog_instance);
#line 316 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		data_imports_ui_data_imports_dialog_instance = _tmp1_;
#line 2119 "DataImportsUI.c"
	}
#line 318 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp2_ = data_imports_ui_data_imports_dialog_instance;
#line 318 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 318 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	result = _tmp3_;
#line 318 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return result;
#line 2129 "DataImportsUI.c"
}


void data_imports_ui_data_imports_dialog_terminate_instance (void) {
	DataImportsUIDataImportsDialog* _tmp0_ = NULL;
#line 322 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = data_imports_ui_data_imports_dialog_instance;
#line 322 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp0_ != NULL) {
#line 2139 "DataImportsUI.c"
		DataImportsUIDataImportsDialog* _tmp1_ = NULL;
#line 323 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp1_ = data_imports_ui_data_imports_dialog_instance;
#line 323 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		data_imports_ui_data_imports_dialog_terminate (_tmp1_);
#line 2145 "DataImportsUI.c"
	}
#line 325 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (data_imports_ui_data_imports_dialog_instance);
#line 325 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_data_imports_dialog_instance = NULL;
#line 2151 "DataImportsUI.c"
}


static gboolean data_imports_ui_data_imports_dialog_on_window_close (DataImportsUIDataImportsDialog* self, GdkEventAny* evt) {
	gboolean result = FALSE;
#line 328 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_val_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self), FALSE);
#line 328 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_val_if_fail (evt != NULL, FALSE);
#line 329 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_debug ("DataImportsUI.vala:329: DataImportsDialog: on_window_close( ): invoked" \
".");
#line 330 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_data_imports_dialog_terminate (self);
#line 332 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	result = TRUE;
#line 332 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return result;
#line 2169 "DataImportsUI.c"
}


static void data_imports_ui_data_imports_dialog_on_service_changed (DataImportsUIDataImportsDialog* self) {
	gchar* service_name = NULL;
	GtkComboBoxText* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	SpitDataImportsService* selected_service = NULL;
	SpitDataImportsService** services = NULL;
	gint _tmp2_ = 0;
	SpitDataImportsService** _tmp3_ = NULL;
	gint services_length1 = 0;
	gint _services_size_ = 0;
	SpitDataImportsService** _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
	SpitDataImportsService* _tmp11_ = NULL;
	ConfigFacade* _tmp12_ = NULL;
	ConfigFacade* _tmp13_ = NULL;
	SpitDataImportsService* _tmp14_ = NULL;
	const gchar* _tmp15_ = NULL;
	SpitDataImportsService* _tmp16_ = NULL;
	SpitDataImportsConcreteDataImportsHost* _tmp17_ = NULL;
	SpitDataImportsConcreteDataImportsHost* _tmp18_ = NULL;
#line 335 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self));
#line 336 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_debug ("DataImportsUI.vala:336: DataImportsDialog: on_service_changed invoked.");
#line 337 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->service_selector_box;
#line 337 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = gtk_combo_box_text_get_active_text (_tmp0_);
#line 337 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	service_name = _tmp1_;
#line 339 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	selected_service = NULL;
#line 340 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp3_ = spit_data_imports_load_all_services (&_tmp2_);
#line 340 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	services = _tmp3_;
#line 340 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	services_length1 = _tmp2_;
#line 340 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_services_size_ = services_length1;
#line 341 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp4_ = services;
#line 341 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp4__length1 = services_length1;
#line 2217 "DataImportsUI.c"
	{
		SpitDataImportsService** service_collection = NULL;
		gint service_collection_length1 = 0;
		gint _service_collection_size_ = 0;
		gint service_it = 0;
#line 341 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		service_collection = _tmp4_;
#line 341 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		service_collection_length1 = _tmp4__length1;
#line 341 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		for (service_it = 0; service_it < _tmp4__length1; service_it = service_it + 1) {
#line 2229 "DataImportsUI.c"
			SpitDataImportsService* _tmp5_ = NULL;
			SpitDataImportsService* service = NULL;
#line 341 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			_tmp5_ = _g_object_ref0 (service_collection[service_it]);
#line 341 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			service = _tmp5_;
#line 2236 "DataImportsUI.c"
			{
				SpitDataImportsService* _tmp6_ = NULL;
				const gchar* _tmp7_ = NULL;
				const gchar* _tmp8_ = NULL;
#line 342 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
				_tmp6_ = service;
#line 342 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
				_tmp7_ = spit_pluggable_get_pluggable_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 342 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
				_tmp8_ = service_name;
#line 342 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
				if (g_strcmp0 (_tmp7_, _tmp8_) == 0) {
#line 2249 "DataImportsUI.c"
					SpitDataImportsService* _tmp9_ = NULL;
					SpitDataImportsService* _tmp10_ = NULL;
#line 343 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp9_ = service;
#line 343 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_tmp10_ = _g_object_ref0 (_tmp9_);
#line 343 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_g_object_unref0 (selected_service);
#line 343 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					selected_service = _tmp10_;
#line 344 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					_g_object_unref0 (service);
#line 344 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
					break;
#line 2264 "DataImportsUI.c"
				}
#line 341 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
				_g_object_unref0 (service);
#line 2268 "DataImportsUI.c"
			}
		}
	}
#line 347 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp11_ = selected_service;
#line 347 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_vala_assert (_tmp11_ != NULL, "selected_service != null");
#line 349 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp12_ = config_facade_get_instance ();
#line 349 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp13_ = _tmp12_;
#line 349 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp14_ = selected_service;
#line 349 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp15_ = spit_pluggable_get_id (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 349 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	configuration_facade_set_last_used_dataimports_service (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp15_);
#line 349 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (_tmp13_);
#line 351 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp16_ = selected_service;
#line 351 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp17_ = spit_data_imports_concrete_data_imports_host_new (_tmp16_, self);
#line 351 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->host);
#line 351 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv->host = _tmp17_;
#line 352 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp18_ = self->priv->host;
#line 352 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	spit_data_imports_plugin_host_start_importing (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 335 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	services = (_vala_array_free (services, services_length1, (GDestroyNotify) g_object_unref), NULL);
#line 335 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (selected_service);
#line 335 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_free0 (service_name);
#line 2306 "DataImportsUI.c"
}


static void data_imports_ui_data_imports_dialog_on_close_cancel_clicked (DataImportsUIDataImportsDialog* self) {
#line 355 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self));
#line 356 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_debug ("DataImportsUI.vala:356: DataImportsDialog: on_close_cancel_clicked( ):" \
" invoked.");
#line 358 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_data_imports_dialog_terminate (self);
#line 2317 "DataImportsUI.c"
}


static void data_imports_ui_data_imports_dialog_terminate (DataImportsUIDataImportsDialog* self) {
	SpitDataImportsConcreteDataImportsHost* _tmp0_ = NULL;
#line 361 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self));
#line 362 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_debug ("DataImportsUI.vala:362: DataImportsDialog: terminate( ): invoked.");
#line 364 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->host;
#line 364 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp0_ != NULL) {
#line 2331 "DataImportsUI.c"
		SpitDataImportsConcreteDataImportsHost* _tmp1_ = NULL;
#line 365 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp1_ = self->priv->host;
#line 365 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		spit_data_imports_plugin_host_stop_importing (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 366 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (self->priv->host);
#line 366 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		self->priv->host = NULL;
#line 2341 "DataImportsUI.c"
	}
#line 369 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 370 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 371 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (data_imports_ui_data_imports_dialog_instance);
#line 371 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_data_imports_dialog_instance = NULL;
#line 2351 "DataImportsUI.c"
}


static void data_imports_ui_data_imports_dialog_set_large_window_mode (DataImportsUIDataImportsDialog* self) {
	GtkBox* _tmp0_ = NULL;
#line 374 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self));
#line 375 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_set_size_request (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_LARGE_WINDOW_WIDTH, DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_LARGE_WINDOW_HEIGHT);
#line 376 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->central_area_layouter;
#line 376 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_set_size_request (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_LARGE_WINDOW_WIDTH - DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_BORDER_REGION_WIDTH, DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_LARGE_WINDOW_HEIGHT - DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_BORDER_REGION_HEIGHT);
#line 378 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), FALSE);
#line 2367 "DataImportsUI.c"
}


static void data_imports_ui_data_imports_dialog_set_colossal_window_mode (DataImportsUIDataImportsDialog* self) {
	GtkBox* _tmp0_ = NULL;
#line 381 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self));
#line 382 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_set_size_request (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_COLOSSAL_WINDOW_WIDTH, DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_COLOSSAL_WINDOW_HEIGHT);
#line 383 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->central_area_layouter;
#line 383 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_set_size_request (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_COLOSSAL_WINDOW_WIDTH - DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_BORDER_REGION_WIDTH, DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_COLOSSAL_WINDOW_HEIGHT - DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_BORDER_REGION_HEIGHT);
#line 385 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), FALSE);
#line 2383 "DataImportsUI.c"
}


static void data_imports_ui_data_imports_dialog_set_standard_window_mode (DataImportsUIDataImportsDialog* self) {
	GtkBox* _tmp0_ = NULL;
#line 388 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self));
#line 389 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_set_size_request (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_STANDARD_WINDOW_WIDTH, DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_STANDARD_WINDOW_HEIGHT);
#line 390 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->central_area_layouter;
#line 390 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_set_size_request (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_STANDARD_WINDOW_WIDTH - DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_BORDER_REGION_WIDTH, DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_STANDARD_WINDOW_HEIGHT - DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_BORDER_REGION_HEIGHT);
#line 392 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), FALSE);
#line 2399 "DataImportsUI.c"
}


static void data_imports_ui_data_imports_dialog_set_free_sizable_window_mode (DataImportsUIDataImportsDialog* self) {
#line 395 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self));
#line 396 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), TRUE);
#line 2408 "DataImportsUI.c"
}


static void data_imports_ui_data_imports_dialog_clear_free_sizable_window_mode (DataImportsUIDataImportsDialog* self) {
#line 399 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self));
#line 400 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), FALSE);
#line 2417 "DataImportsUI.c"
}


SpitDataImportsDialogPane* data_imports_ui_data_imports_dialog_get_active_pane (DataImportsUIDataImportsDialog* self) {
	SpitDataImportsDialogPane* result = NULL;
	SpitDataImportsDialogPane* _tmp0_ = NULL;
	SpitDataImportsDialogPane* _tmp1_ = NULL;
#line 403 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_val_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self), NULL);
#line 404 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->active_pane;
#line 404 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 404 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	result = _tmp1_;
#line 404 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	return result;
#line 2435 "DataImportsUI.c"
}


void data_imports_ui_data_imports_dialog_set_close_button_mode (DataImportsUIDataImportsDialog* self) {
	GtkButton* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GtkButton* _tmp2_ = NULL;
#line 407 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self));
#line 408 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->close_cancel_button;
#line 408 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = _ ("_Close");
#line 408 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_button_set_label (_tmp0_, _tmp1_);
#line 409 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp2_ = self->priv->close_cancel_button;
#line 409 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_window_set_default (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget));
#line 2455 "DataImportsUI.c"
}


void data_imports_ui_data_imports_dialog_set_cancel_button_mode (DataImportsUIDataImportsDialog* self) {
	GtkButton* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 412 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self));
#line 413 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->close_cancel_button;
#line 413 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp1_ = _ ("_Cancel");
#line 413 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_button_set_label (_tmp0_, _tmp1_);
#line 2470 "DataImportsUI.c"
}


void data_imports_ui_data_imports_dialog_lock_service (DataImportsUIDataImportsDialog* self) {
	GtkComboBoxText* _tmp0_ = NULL;
#line 416 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self));
#line 417 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->service_selector_box;
#line 417 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 2482 "DataImportsUI.c"
}


void data_imports_ui_data_imports_dialog_unlock_service (DataImportsUIDataImportsDialog* self) {
	GtkComboBoxText* _tmp0_ = NULL;
#line 420 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self));
#line 421 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->service_selector_box;
#line 421 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 2494 "DataImportsUI.c"
}


void data_imports_ui_data_imports_dialog_install_pane (DataImportsUIDataImportsDialog* self, SpitDataImportsDialogPane* pane) {
	SpitDataImportsDialogPane* _tmp0_ = NULL;
	GtkBox* _tmp6_ = NULL;
	SpitDataImportsDialogPane* _tmp7_ = NULL;
	GtkWidget* _tmp8_ = NULL;
	GtkWidget* _tmp9_ = NULL;
	SpitDataImportsDialogPaneGeometryOptions geometry_options = 0;
	SpitDataImportsDialogPane* _tmp10_ = NULL;
	SpitDataImportsDialogPaneGeometryOptions _tmp11_ = 0;
	SpitDataImportsDialogPaneGeometryOptions _tmp12_ = 0;
	SpitDataImportsDialogPaneGeometryOptions _tmp14_ = 0;
	SpitDataImportsDialogPane* _tmp15_ = NULL;
	SpitDataImportsDialogPane* _tmp16_ = NULL;
	SpitDataImportsDialogPane* _tmp17_ = NULL;
#line 424 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (self));
#line 424 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_return_if_fail (SPIT_DATA_IMPORTS_IS_DIALOG_PANE (pane));
#line 425 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_debug ("DataImportsUI.vala:425: DataImportsDialog: install_pane( ): invoked.");
#line 427 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp0_ = self->priv->active_pane;
#line 427 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if (_tmp0_ != NULL) {
#line 2522 "DataImportsUI.c"
		SpitDataImportsDialogPane* _tmp1_ = NULL;
		GtkBox* _tmp2_ = NULL;
		SpitDataImportsDialogPane* _tmp3_ = NULL;
		GtkWidget* _tmp4_ = NULL;
		GtkWidget* _tmp5_ = NULL;
#line 428 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		g_debug ("DataImportsUI.vala:428: DataImportsDialog: install_pane( ): a pane is " \
"already installed; removing it.");
#line 430 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp1_ = self->priv->active_pane;
#line 430 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		spit_data_imports_dialog_pane_on_pane_uninstalled (_tmp1_);
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp2_ = self->priv->central_area_layouter;
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp3_ = self->priv->active_pane;
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp4_ = spit_data_imports_dialog_pane_get_widget (_tmp3_);
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp5_ = _tmp4_;
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		gtk_container_remove (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_container_get_type (), GtkContainer), _tmp5_);
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_g_object_unref0 (_tmp5_);
#line 2546 "DataImportsUI.c"
	}
#line 434 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp6_ = self->priv->central_area_layouter;
#line 434 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp7_ = pane;
#line 434 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp8_ = spit_data_imports_dialog_pane_get_widget (_tmp7_);
#line 434 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp9_ = _tmp8_;
#line 434 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_box_pack_start (_tmp6_, _tmp9_, TRUE, TRUE, (guint) 0);
#line 434 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (_tmp9_);
#line 435 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 437 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp10_ = pane;
#line 437 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp11_ = spit_data_imports_dialog_pane_get_preferred_geometry (_tmp10_);
#line 437 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	geometry_options = _tmp11_;
#line 439 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp12_ = geometry_options;
#line 439 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if ((_tmp12_ & SPIT_PUBLISHING_DIALOG_PANE_GEOMETRY_OPTIONS_EXTENDED_SIZE) != 0) {
#line 440 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		data_imports_ui_data_imports_dialog_set_large_window_mode (self);
#line 2574 "DataImportsUI.c"
	} else {
		SpitDataImportsDialogPaneGeometryOptions _tmp13_ = 0;
#line 441 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		_tmp13_ = geometry_options;
#line 441 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		if ((_tmp13_ & SPIT_PUBLISHING_DIALOG_PANE_GEOMETRY_OPTIONS_COLOSSAL_SIZE) != 0) {
#line 442 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			data_imports_ui_data_imports_dialog_set_colossal_window_mode (self);
#line 2583 "DataImportsUI.c"
		} else {
#line 444 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
			data_imports_ui_data_imports_dialog_set_standard_window_mode (self);
#line 2587 "DataImportsUI.c"
		}
	}
#line 446 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp14_ = geometry_options;
#line 446 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	if ((_tmp14_ & SPIT_PUBLISHING_DIALOG_PANE_GEOMETRY_OPTIONS_RESIZABLE) != 0) {
#line 447 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		data_imports_ui_data_imports_dialog_set_free_sizable_window_mode (self);
#line 2596 "DataImportsUI.c"
	} else {
#line 449 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
		data_imports_ui_data_imports_dialog_clear_free_sizable_window_mode (self);
#line 2600 "DataImportsUI.c"
	}
#line 451 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp15_ = pane;
#line 451 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp16_ = _g_object_ref0 (_tmp15_);
#line 451 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->active_pane);
#line 451 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv->active_pane = _tmp16_;
#line 452 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_tmp17_ = pane;
#line 452 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	spit_data_imports_dialog_pane_on_pane_installed (_tmp17_);
#line 2614 "DataImportsUI.c"
}


static void data_imports_ui_data_imports_dialog_class_init (DataImportsUIDataImportsDialogClass * klass) {
#line 191 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	data_imports_ui_data_imports_dialog_parent_class = g_type_class_peek_parent (klass);
#line 191 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	g_type_class_add_private (klass, sizeof (DataImportsUIDataImportsDialogPrivate));
#line 191 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	G_OBJECT_CLASS (klass)->finalize = data_imports_ui_data_imports_dialog_finalize;
#line 2625 "DataImportsUI.c"
}


static void data_imports_ui_data_imports_dialog_instance_init (DataImportsUIDataImportsDialog * self) {
#line 191 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self->priv = DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_GET_PRIVATE (self);
#line 2632 "DataImportsUI.c"
}


static void data_imports_ui_data_imports_dialog_finalize (GObject* obj) {
	DataImportsUIDataImportsDialog * self;
#line 191 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG, DataImportsUIDataImportsDialog);
#line 204 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->service_selector_box);
#line 205 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->central_area_layouter);
#line 206 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->close_cancel_button);
#line 207 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->active_pane);
#line 208 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	_g_object_unref0 (self->priv->host);
#line 191 "/home/jens/Source/shotwell/src/data_imports/DataImportsUI.vala"
	G_OBJECT_CLASS (data_imports_ui_data_imports_dialog_parent_class)->finalize (obj);
#line 2652 "DataImportsUI.c"
}


GType data_imports_ui_data_imports_dialog_get_type (void) {
	static volatile gsize data_imports_ui_data_imports_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_ui_data_imports_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsUIDataImportsDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_ui_data_imports_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsUIDataImportsDialog), 0, (GInstanceInitFunc) data_imports_ui_data_imports_dialog_instance_init, NULL };
		GType data_imports_ui_data_imports_dialog_type_id;
		data_imports_ui_data_imports_dialog_type_id = g_type_register_static (gtk_dialog_get_type (), "DataImportsUIDataImportsDialog", &g_define_type_info, 0);
		g_once_init_leave (&data_imports_ui_data_imports_dialog_type_id__volatile, data_imports_ui_data_imports_dialog_type_id);
	}
	return data_imports_ui_data_imports_dialog_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



